@@ -56,6 +56,7 @@
 #include "wrap.h"
 #include "status.h"
 #include "parse_xml.h"
+#include "flmsg_strings.h"
 
 #ifdef WIN32
 #  include "flmsgrc.h"
@@ -293,7 +294,7 @@ void cap105_read_buffer(string data)
 void cap105_cb_new()
 {
 	if (cap105_check_fields()) {
-		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 1) {
+		if (fl_choice2(xMODIFIED, xNO, xYES, NULL) == 1) {
 			update_header(CHANGED);
 			cap105_cb_save();
 		}
@@ -302,19 +303,19 @@ void cap105_cb_new()
 	cap105_clear_form();
 	clear_header();
 	cap105_def_filename = ICS_msg_dir;
-	cap105_def_filename.append("new"CAP105_FILE_EXT);
+	cap105_def_filename.append(xNEW).append(CAP105_FILE_EXT);
 	cap105_using_template = false;
 	show_filename(cap105_def_filename);
 }
 
 void cap105_cb_import()
 {
-	fl_alert2("Not implemented");
+	fl_alert2(xNOTIMPLEMENTED);
 }
 
 void cap105_cb_export()
 {
-	fl_alert2("Not implemented");
+	fl_alert2(xNOTIMPLEMENTED);
 }
 
 void cap105_cb_wrap_import(string wrapfilename, string inpbuffer)
@@ -346,21 +347,22 @@ int eval_cap105_fsize()
 void cap105_cb_wrap_export()
 {
 	if (cap105_check_fields()) {
-		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+		if (fl_choice2(xMODIFIED, xNO, xYES, NULL) == 0)
 			return;
 		update_header(CHANGED);
 	}
 	cap105_update_fields();
 
-	if (cap105_base_filename == "new"CAP105_FILE_EXT || cap105_base_filename == "default"CAP105_FILE_EXT)
+	if (cap105_base_filename == string(xNEW).append(CAP105_FILE_EXT) || 
+		cap105_base_filename == string(xDEFAULT).append(CAP105_FILE_EXT) )
 		if (!cap105_cb_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
 	wrapfilename.append(cap105_base_filename);
 	wrapfilename.append(WRAP_EXT);
 	const char *p = FSEL::saveas(
-			"Save as wrapped cap105 file",
-			"Wrap file\t*.{wrap,WRAP}",
+			xSAVEASWRAP,
+			xWRAPFILE,
 			wrapfilename.c_str());
 	if (p) {
 		string pext = fl_filename_ext(p);
@@ -380,13 +382,14 @@ void cap105_cb_wrap_export()
 void cap105_cb_wrap_autosend()
 {
 	if (cap105_check_fields()) {
-		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+		if (fl_choice2(xMODIFIED, xNO, xYES, NULL) == 0)
 			return;
 		update_header(CHANGED);
 	}
 	cap105_update_fields();
 
-	if (cap105_base_filename == "new"CAP105_FILE_EXT || cap105_base_filename == "default"CAP105_FILE_EXT)
+	if (cap105_base_filename == string(xNEW).append(CAP105_FILE_EXT) || 
+		cap105_base_filename == string(xDEFAULT).append(CAP105_FILE_EXT) )
 		if (!cap105_cb_save_as()) return;
 
 	update_header(FROM);
@@ -403,8 +406,8 @@ void cap105_cb_load_template()
 {
 	string cap105_def_filename = cap105_def_template_name;
 	const char *p = FSEL::select(
-			"Open template file",
-			"Template file\t*"CAP105_TEMP_EXT,
+			xOPENTEMPLATE,
+			string(xTEMPLATEFILE).append(CAP105_TEMP_EXT).c_str(),
 			cap105_def_filename.c_str());
 	if (p) {
 		cap105_clear_form();
@@ -423,8 +426,8 @@ void cap105_cb_save_template()
 	}
 	string cap105_def_filename = cap105_def_template_name;
 	const char *p = FSEL::saveas(
-			"Save template file",
-			"Template file\t*"CAP105_TEMP_EXT,
+			xSAVEASTEMPLATE,
+			string(xTEMPLATEFILE).append(CAP105_TEMP_EXT).c_str(),
 			cap105_def_filename.c_str());
 	if (p) {
 		update_header(CHANGED);
@@ -439,8 +442,8 @@ void cap105_cb_save_as_template()
 {
 	string cap105_def_filename = cap105_def_template_name;
 	const char *p = FSEL::saveas(
-			"Save as template file",
-			"Template file\t*"CAP105_TEMP_EXT,
+			xSAVEASTEMPLATE,
+			string(xTEMPLATEFILE).append(CAP105_TEMP_EXT).c_str(),
 			cap105_def_filename.c_str());
 	if (p) {
 		const char *pext = fl_filename_ext(p);
@@ -462,8 +465,10 @@ void cap105_cb_save_as_template()
 
 void cap105_cb_open()
 {
-	const char *p = FSEL::select(_("Open data file"), "cap105\t*"CAP105_FILE_EXT,
-					cap105_def_filename.c_str());
+	const char *p = FSEL::select(
+			_(xOPENDATAFILE), 
+			string("cap105\t*").append(CAP105_FILE_EXT).c_str(),
+			cap105_def_filename.c_str());
 	if (!p) return;
 	if (strlen(p) == 0) return;
 	cap105_clear_form();
@@ -495,8 +500,9 @@ bool cap105_cb_save_as()
 	} else
 		newfilename = cap105_def_filename;
 
-	p = FSEL::saveas(_("Save data file"), "cap105\t*"CAP105_FILE_EXT,
-						newfilename.c_str());
+	p = FSEL::saveas(_(xSAVEDATAFILE), 
+				string("cap105\t*").append(CAP105_FILE_EXT).c_str(),
+				newfilename.c_str());
 
 	if (!p) return false;
 	if (strlen(p) == 0) return false;
@@ -509,15 +515,9 @@ bool cap105_cb_save_as()
 		progStatus.rgnbr = szn;
 		txt_rgnbr->value(szn);
 		txt_rgnbr->redraw();
-	} else if (progStatus.sernbr_fname) {
-		int n = atoi(progStatus.sernbr.c_str());
-		n++;
-		char szn[10];
-		snprintf(szn, sizeof(szn), "%d", n);
-		progStatus.sernbr = szn;
-		txt_sernbr->value(szn);
-		txt_sernbr->redraw();
-	}
+	} else if (progStatus.sernbr_fname)
+		update_sernbr();
+
 	const char *pext = fl_filename_ext(p);
 	cap105_def_filename = p;
 	if (strlen(pext) == 0) cap105_def_filename.append(CAP105_FILE_EXT);
@@ -537,8 +537,8 @@ bool cap105_cb_save_as()
 
 void cap105_cb_save()
 {
-	if (cap105_base_filename == "new"CAP105_FILE_EXT || 
-		cap105_base_filename == "default"CAP105_FILE_EXT ||
+	if (cap105_base_filename == string(xNEW).append(CAP105_FILE_EXT) || 
+		cap105_base_filename == string(xDEFAULT).append(CAP105_FILE_EXT) ||
 		cap105_using_template == true) {
 		cap105_cb_save_as();
 		return;
@@ -618,7 +618,7 @@ void cap105_cb_check()
 	}
 */
 
-	char snum[10];
+	char snum[15];
 	snprintf(snum, sizeof(snum), "%d", numwords);
 	cap105_grpcnt = snum;
 	cap105_txt_grpcnt->value(snum);
@@ -631,7 +631,7 @@ void cap105_cb_html()
 {
 	string cap105_name;
 	string html_text;
-	size_t nbr;
+	unsigned int nbr;
 	cap105_name = ICS_dir;
 	cap105_name.append("cap105.html");
 
@@ -646,7 +646,7 @@ string pgone = "1";
 	replacestr( form, pgnr, pgone);
 	for (int i = 0; i < cap105_num_fields; i++) {
 		if (cap105_fields[i].f_type == cap105_prec) {
-			sscanf(cap105_fields[i].f_data.c_str(), "%d", &nbr);
+			sscanf(cap105_fields[i].f_data.c_str(), "%u", &nbr);
 			if (nbr >= 0 && nbr < (sizeof(cap105_s_prec) / sizeof(*cap105_s_prec)))
 				html_text = cap105_s_prec[nbr];
 			else
