@@ -90,12 +90,11 @@ extern int custom_select;
 
 extern struct mg_server *server;
 
-static string action_str   = "\n<FORM ACTION=\"/handle_post_request\" METHOD=\"post\">\n";
-static string submit_str   = "\n<INPUT TYPE=\"submit\" VALUE=\"Submit Form\">\n</form>";
+static string action_str   = "\n<FORM ACTION=\"/handle_post_request\" METHOD=\"post\" \n";
+static string submit_str   = "\n<INPUT TYPE=\"submit\" VALUE=\"Submit Form\">\n</form ";
 static string input_str    = "<INPUT";
 static string select_str   = "<SELECT";
 static string end_sel_str  = "</SELECT";
-//static string option_str   = "<OPTION";
 static string textarea_str = "<TEXTAREA";
 static string textend_str  = "</TEXTAREA";
 static string checked      = "CHECKED";
@@ -109,17 +108,19 @@ static string text_type_str =      "TYPE=\"TEXT\"";
 static string radio_type_str =     "TYPE=\"RADIO\"";
 static string checkbox_type_str =  "TYPE=\"CHECKBOX\"";
 static string password_type_str =  "TYPE=\"PASSWORD\"";
-static string number_str =    "TYPE=\"NUMBER\"";
+static string number_str =         "TYPE=\"NUMBER\"";
 static string date_str =           "TYPE=\"DATE\"";
 static string datetime_str =       "TYPE=\"DATETIME\"";
 static string datetime_local_str = "TYPE=\"DATETIME-LOCAL\"";
 static string time_str =           "TYPE=\"TIME\"";
 static string week_str =           "TYPE=\"WEEK\"";
 static string month_str =          "TYPE=\"MONTH\"";
+static string tel_str =            "TYPE=\"TEL\"";
+static string email_str =          "TYPE=\"EMAIL\"";
 
 enum {
 	T_TEXT, T_RADIO, T_CHECKBOX, T_AREA, T_SELECT, T_PASSWORD,
-	T_NUMBER, T_DATE, T_DTIME, T_DTIME_LOCAL, T_TIME, T_WEEK, T_MONTH };
+	T_NUMBER, T_DATE, T_DTIME, T_DTIME_LOCAL, T_TIME, T_WEEK, T_MONTH, T_TEL, T_EMAIL };
 
 struct INPUT_TYPE {
 	int id;
@@ -143,7 +144,9 @@ static INPUT_TYPE input_types[] = {
 	INPUT_TYPE(T_DTIME_LOCAL, datetime_local_str),
 	INPUT_TYPE(T_TIME, time_str),
 	INPUT_TYPE(T_WEEK, week_str),
-	INPUT_TYPE(T_MONTH, month_str)
+	INPUT_TYPE(T_MONTH, month_str),
+	INPUT_TYPE(T_TEL, tel_str),
+	INPUT_TYPE(T_EMAIL, email_str)
 };
 
 struct NAME_VALUE {
@@ -206,38 +209,50 @@ void unescape(string &s)
 
 int convert_case(string &s)
 {
-	extstring mystring;
-	mystring.assign(s);
-	if (mystring.ufind("<FORM", 0) == string::npos ||
-		mystring.ufind("</FORM", 0) == string::npos )
+	std::string s1, s3;
+	extstring s2;//s1;
+	s2.assign(s);
+
+	size_t p1 = s2.ufind("<body", 0);
+	s1 = s2.substr(0, p1);
+	s2.erase(0, p1);
+	p1 = s2.ufind("</body", 0);
+	s3 = s2.substr(p1);
+	s2.erase(p1);
+
+	if (s2.ufind("<FORM", 0) == string::npos ||
+		s2.ufind("</FORM", 0) == string::npos )
 		return 1;
-	mystring.ureplace("<FORM");
-	mystring.ureplace("</FORM");
-	mystring.ureplace("<INPUT");
-	mystring.ureplace("<TEXTAREA");
-	mystring.ureplace("</TEXTAREA");
-	mystring.ureplace("VALUE=\"");
-	mystring.ureplace("NAME=\"");
-	mystring.ureplace("TYPE=\"");
-	mystring.ureplace("=\"TEXT\"");
-	mystring.ureplace("=\"RADIO\"");
-	mystring.ureplace("=\"CHECKBOX\"");
-	mystring.ureplace("=\"PASSWORD\"");
+	s2.ureplace("<FORM");
+	s2.ureplace("</FORM");
+	s2.ureplace("<INPUT");
+	s2.ureplace("<TEXTAREA");
+	s2.ureplace("</TEXTAREA");
+	s2.ureplace("VALUE=\"");
+	s2.ureplace("NAME=\"");
+	s2.ureplace("TYPE=\"");
+	s2.ureplace("=\"TEXT\"");
+	s2.ureplace("=\"RADIO\"");
+	s2.ureplace("=\"CHECKBOX\"");
+	s2.ureplace("=\"PASSWORD\"");
 
-	mystring.ureplace("=\"NUMBER\"");
-	mystring.ureplace("=\"DATE\"");
-	mystring.ureplace("=\"DATETIME\"");
-	mystring.ureplace("=\"DATETIME-LOCAL\"");
-	mystring.ureplace("=\"TIME\"");
-	mystring.ureplace("=\"WEEK\"");
-	mystring.ureplace("=\"MONTH\"");
+	s2.ureplace("=\"NUMBER\"");
+	s2.ureplace("=\"DATE\"");
+	s2.ureplace("=\"DATETIME\"");
+	s2.ureplace("=\"DATETIME-LOCAL\"");
+	s2.ureplace("=\"TIME\"");
+	s2.ureplace("=\"WEEK\"");
+	s2.ureplace("=\"MONTH\"");
+	s2.ureplace("=\"TEL\"");
+	s2.ureplace("=\"EMAIL\"");
 
-	mystring.ureplace("SELECTED");
-	mystring.ureplace("CHECKED");
-	mystring.ureplace("<SELECT");
-	mystring.ureplace("</SELECT");
-//	mystring.ureplace("<OPTION");
-	s.assign(mystring);
+	s2.ureplace("SELECTED");
+	s2.ureplace("CHECKED");
+	s2.ureplace("<SELECT");
+	s2.ureplace("</SELECT");
+//	s2.ureplace("<OPTION");
+	s.assign(s1).append(s2).append(s3);
+//	s.assign(s1);
 	return 0;
 }
 
@@ -246,7 +261,6 @@ int convert_case(string &s)
 // clears the html form of those value.
 void extract_fields()
 {
-//printf("custom select %d\n", custom_select);
 	if (custom_select < 0) return;
 	string fname = CUSTOM_dir;
 	{
@@ -300,7 +314,7 @@ void extract_fields()
 			switch (input_types[i].id) {
 				case T_TEXT: case T_PASSWORD: case T_NUMBER:
 				case T_DATE: case T_DTIME: case T_DTIME_LOCAL:
-				case T_TIME: case T_WEEK:  case T_MONTH:
+				case T_TIME: case T_WEEK:  case T_MONTH: case T_TEL: case T_EMAIL:
 					pvalue = html_form.find(value_str, pstart);
 					if (pvalue == string::npos || pvalue > pend) break;
 					pvalue += value_str.length();
@@ -323,13 +337,13 @@ void extract_fields()
 						field_value.clear();
 						p2 = html_form.find(checkedeq, pstart);
 						if (p2 < pend) {
-							field_value = checked;
+							field_value = "Y";//checked;
 							html_form.erase(p2 - 1, checkedeq.length() + 1);
 							pend = html_form.find(">", pstart);
 						} else {
 							p2 = html_form.find(checked, pstart);
 							if (p2 < pend) {
-								field_value = checked;
+								field_value = "Y";//checked;
 								html_form.erase(p2 - 1, checked.length() + 1);
 								pend = html_form.find(">", pstart);
 							}
@@ -349,19 +363,19 @@ void extract_fields()
 					field_value.clear();
 					p2 = html_form.find(checkedeq, pstart);
 					if (p2 < pend) {
-						field_value = "ON";
+						field_value = "Y";//"ON";
 						html_form.erase(p2 - 1, checkedeq.length() + 1);
 						pend = html_form.find(">", pstart);
 					} else {
 						p2 = html_form.find(checked, pstart);
 						if (p2 < pend) {
-							field_value = "ON";
+							field_value = "Y";//"ON";
 							html_form.erase(p2 - 1, checked.length() + 1);
 							pend = html_form.find(">", pstart);
 						} else {
 							p2 = html_form.find(" ON", pstart);
 							if (p2 < pend) {
-								field_value = "ON";
+								field_value = "Y";//"ON";
 								html_form.erase(p2, 3);
 								pend = html_form.find(">", pstart);
 							}
@@ -445,14 +459,14 @@ void get_html_vars(struct mg_connection *conn)
 			case T_RADIO :
 				p = name_values[n].name.find(".");
 				if (name_values[n].name.substr(p+1) == buff)
-					name_values[n].value = checked;
+					name_values[n].value = "Y";//checked;
 				line.assign(name_values[n].name)
 					.append(",")
 					.append(name_values[n].value);
 				break;
 			case T_CHECKBOX :
 				if (strstr(buff, "on") == buff || strstr(buff, "ON") == buff)
-					name_values[n].value = "ON";
+					name_values[n].value = "Y";//"ON";
 				line.assign(name_values[n].name)
 					.append(",")
 					.append(name_values[n].value);
@@ -486,7 +500,7 @@ void assign_values(string &html)
 		switch (name_values[n].id) {
 			case T_TEXT : case T_PASSWORD : case T_NUMBER :
 			case T_DATE : case T_DTIME : case T_DTIME_LOCAL :
-			case T_TIME : case T_WEEK :  case T_MONTH :
+			case T_TIME : case T_WEEK :  case T_MONTH : case T_TEL : case T_EMAIL:
 				nm.assign("NAME=\"").append(name_values[n].name).append("\"");
 				pnm = html.find(nm);
 				if (pnm != string::npos) {
@@ -527,7 +541,8 @@ void assign_values(string &html)
 						continue;
 					}
 				// found name and value pair
-					if (name_values[n].value == checked)
+					if (name_values[n].value == checked ||
+						name_values[n].value == "Y")
 						html.insert(pend, string(" ").append(checked));
 					pend = html.find(">", pbeg);
 					pnm = html.find(nm, pend);
@@ -539,7 +554,8 @@ void assign_values(string &html)
 				if (pnm != string::npos) {
 					pbeg = html.rfind("<", pnm);
 					pend = html.find(">", pbeg);
-					if (name_values[n].value == "ON") {
+					if (name_values[n].value == "ON" ||
+						name_values[n].value == "Y") {
 						html.insert(pend, string(" ").append(checked));
 						pend = html.find(">", pbeg);
 					}
@@ -591,12 +607,12 @@ void assign_values(string &html)
 void custom_editor(struct mg_connection *conn)
 {
 	string html_edit = html_form;
-	size_t p = html_edit.find("<FORM>");
+	size_t p = html_edit.find("<FORM");
 	if (p == string::npos) return;
 
-	html_edit.replace(p, 6, action_str);
-	p = html_edit.find("</FORM>");
-	html_edit.replace(p, 7, submit_str);
+	html_edit.replace(p, 5, action_str);
+	p = html_edit.find("</FORM");
+	html_edit.replace(p, 6, submit_str);
 	assign_values(html_edit);
 	mg_send_data(conn, html_edit.c_str(), html_edit.length());
 }
@@ -610,7 +626,7 @@ void custom_viewer(struct mg_connection *conn)
 // add readonly attribute to all input controls
 	size_t pstart, ptext, pradio, pcheckbox, ppassword, pnumber,
 		   pdate, pdtime, pdtime_local, pweek, pmonth,
-		   pend;
+		   ptel, pemail, pend;
 
 	pstart = html_view.find("<INPUT");
 	while (pstart != string::npos) {
@@ -625,14 +641,11 @@ void custom_viewer(struct mg_connection *conn)
 		pdtime_local = html_view.find(datetime_local_str, pstart);
 		pweek = html_view.find(week_str, pstart);
 		pmonth = html_view.find(month_str, pstart);
+		ptel = html_view.find(tel_str, pstart);
+		pemail = html_view.find(email_str, pstart);
 
 		if (ppassword < pend) {
 			size_t pvalue = html_view.find("VALUE=\"", pstart);
-//std::cout << "pstart " << pstart << "\n";
-//std::cout << "ppassword " << ppassword << "\n";
-//std::cout << "pend " << pend << "\n";
-//std::cout << "pvalue " << pvalue << "\n";
-//std::cout << html_view.substr(pstart, pend-pstart+1) << "\n";
 			if (pvalue < pend) {
 				pvalue += 7;
 				while (html_view[pvalue] != '\"') {
@@ -644,7 +657,7 @@ void custom_viewer(struct mg_connection *conn)
 			html_view.insert(pstart + 6, " READONLY");
 		} else if (ptext < pend || pnumber < pend ||
 				  pdate < pend || pdtime < pend || pdtime_local < pend ||
-				  pweek < pend || pmonth < pend)
+				  pweek < pend || pmonth < pend || ptel < pend || pemail < pend)
 			html_view.insert(pstart + 6, " READONLY");
 		else if (pradio < pend || pcheckbox < pend)
 			html_view.insert(pstart + 6, " DISABLED");
@@ -739,10 +752,6 @@ void text_to_pairs()
 				escape(val);
 			name_values[n].value = val;
 		}
-std::cout << 
-	"name " << name_values[n].name << 
-	", value " << name_values[n].value << 
-	"\n";
 	}
 }
 
@@ -762,6 +771,7 @@ void pairs_to_text()
 
 std::string min_pairs_to_text()
 {
+	if (custom_select == -1) return "";
 	static std::string mintext;
 	mintext.clear();
 	mintext.assign("CUSTOM_FORM,")
@@ -782,9 +792,7 @@ void update_customform()
 	extract_fields();
 	edit_txt = custom_field;
 	text_to_pairs();
-//printf("B\n%s\n", edit_txt.c_str());
 	pairs_to_text();
-//printf("C\n%s\n", edit_txt.c_str());
 	txt_custom_msg->clear();
 	txt_custom_msg->add(edit_txt.c_str());
 }
@@ -807,7 +815,6 @@ void read_custombuffer(string data)
 	string fname = custom_field.substr(p0, p1-p0);
 	string html_fname = CUSTOM_dir;
 	html_fname.append(fname);
-//printf("form file: %s\n", html_fname.c_str());
 
 	{ // treat this block as a critical section
 		guard_lock web_lock(&mutex_web_server);
@@ -830,13 +837,13 @@ void cb_custom_new()
 	if (check_customfields()) {
 		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 1) {
 			update_header(CHANGED);
-			cb_custom_save();
+			cb_custom_save_as();
 		}
 	}
 	clear_custom_form();
 	clear_header();
 	def_custom_filename = ICS_msg_dir;
-	def_custom_filename.append("new"CUSTOMFILE_EXT);
+	def_custom_filename.append("new").append(CUSTOMFILE_EXT);
 	show_filename(def_custom_filename);
 	using_custom_template = false;
 }
@@ -887,7 +894,8 @@ void cb_custom_wrap_export()
 	string wfields = min_pairs_to_text();
 	if (wfields.empty()) return;
 
-	if (base_custom_filename == "new"CUSTOMFILE_EXT || base_custom_filename == "default"CUSTOMFILE_EXT)
+	if (base_custom_filename == string("new").append(CUSTOMFILE_EXT) ||
+		base_custom_filename == string("default").append(CUSTOMFILE_EXT) )
 		if (!cb_custom_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
@@ -922,7 +930,8 @@ void cb_custom_wrap_autosend()
 	string wfields = min_pairs_to_text();
 	if (wfields.empty()) return;
 
-	if (base_custom_filename == "new"CUSTOMFILE_EXT || base_custom_filename == "default"CUSTOMFILE_EXT)
+	if (base_custom_filename == string("new").append(CUSTOMFILE_EXT) ||
+		base_custom_filename == string("default").append(CUSTOMFILE_EXT) )
 		if (!cb_custom_save_as()) return;
 
 	update_header(FROM);
@@ -951,7 +960,7 @@ void cb_custom_save_template()
 	string def_custom_filename = def_custom_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save template file",
-			"Template file\t*"CUSTOMTEMP_EXT,
+			string("Template file\t*").append(CUSTOMTEMP_EXT).c_str(),
 			def_custom_filename.c_str());
 	if (p) {
 		update_header(CHANGED);
@@ -967,7 +976,7 @@ void cb_custom_save_as_template()
 	string def_custom_filename = def_custom_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save as template file",
-			"Template file\t*"CUSTOMTEMP_EXT,
+			string("Template file\t*").append(CUSTOMTEMP_EXT).c_str(),
 			def_custom_filename.c_str());
 	if (p) {
 		const char *pext = fl_filename_ext(p);
@@ -991,6 +1000,10 @@ void cb_custom_open()
 					def_custom_filename.c_str());
 	if (!p) return;
 	if (strlen(p) == 0) return;
+	if ((strstr(p, ".k2s") == NULL) && update_custom) {
+		fl_alert2("Not a custom form");
+		return;
+	}
 	clear_custom_form();
 	read_data_file(p);
 	using_custom_template = false;
@@ -1027,18 +1040,7 @@ bool cb_custom_save_as()
 	if (!p) return false;
 	if (strlen(p) == 0) return false;
 
-	if (progStatus.sernbr_fname) {
-		string haystack = p;
-		if (haystack.find(newfilename) != string::npos) {
-			int n = atoi(progStatus.sernbr.c_str());
-			n++;
-			char szn[10];
-			snprintf(szn, sizeof(szn), "%d", n);
-			progStatus.sernbr = szn;
-			txt_sernbr->value(szn);
-			txt_sernbr->redraw();
-		}
-	}
+	if (progStatus.sernbr_fname) update_sernbr();
 
 	const char *pext = fl_filename_ext(p);
 	def_custom_filename = p;
@@ -1360,3 +1362,11 @@ void cb_btn_select_custom_html(Fl_Widget *w, void *d)
 	show_filename(def_custom_transfer_filename);
 	load_custom_html_file();
 }
+
+void custom_edit() {
+
+	handle_type = HANDLE_EDIT;
+	string url = "http://127.0.0.1:";
+	url.append(sz_srvr_portnbr);
+	open_url(url.c_str());
+}
