@@ -22,6 +22,7 @@
 #include <unistd.h>
 #include <iostream>
 #include <fstream>
+#include <sstream>
 #include <cstring>
 #include <ctime>
 #include <sys/types.h>
@@ -44,6 +45,7 @@
 #include "flmsg_config.h"
 
 #include "flmsg.h"
+#include "flmsg_arq.h"
 
 #include "templates.h"
 #include "debug.h"
@@ -67,6 +69,8 @@
 
 #include "timeops.h"
 
+#include "arq.h"
+
 #ifdef WIN32
 #  include "flmsgrc.h"
 #  include "compat.h"
@@ -82,7 +86,7 @@
 
 using namespace std;
 
-//------------------------------------------------------------------------------
+//----------------------------------------------------------------------
 // Mongoose web server
 struct mg_server *server = (mg_server *)NULL;
 void *poll_server(void *);
@@ -93,12 +97,18 @@ string mongoose_msgs;
 
 int srvr_portnbr = 8080;
 char sz_srvr_portnbr[6];
-//------------------------------------------------------------------------------
+
+//----------------------------------------------------------------------
+// log files
+void rotate_log(std::string filename);
+//----------------------------------------------------------------------
 
 const char *options[] = {\
 "flmsg unique options",
 "--help",
 "--version",
+"--viewer\topen as custom viewer - no main dialog",
+"--editor\topen as custom editor - no main dialog",
 "--server-port\tstarting port number for forms web server [8080]",
 "--flmsg-dir\tfull-path-name-of-folder for all FLMSG folders",
 "--auto-dir\tfull-path-name-of-folder for autosend files",
@@ -125,12 +135,14 @@ const char *options[] = {\
 0
 };
 
-Fl_Double_Window *mainwindow = 0;
-Fl_Double_Window *optionswindow = 0;
-Fl_Double_Window *arlwindow = 0;
-Fl_Double_Window *config_dialog = 0;
-Fl_Double_Window *hxwindow = 0;
-Fl_Double_Window *header_window = 0;
+Fl_Double_Window *mainwindow = (Fl_Double_Window *)0;
+Fl_Double_Window *expert_dialog = (Fl_Double_Window *)0;
+Fl_Double_Window *tyro_dialog = (Fl_Double_Window *)0;
+Fl_Double_Window *optionswindow = (Fl_Double_Window *)0;
+Fl_Double_Window *arlwindow = (Fl_Double_Window *)0;
+Fl_Double_Window *config_dialog = (Fl_Double_Window *)0;
+Fl_Double_Window *hxwindow = (Fl_Double_Window *)0;
+Fl_Double_Window *header_window = (Fl_Double_Window *)0;
 
 pthread_t *xmlrpc_thread = 0;
 pthread_mutex_t mutex_xmlrpc = PTHREAD_MUTEX_INITIALIZER;
@@ -159,7 +171,7 @@ string ARQ_send_dir = "";
 string WRAP_dir = "";
 string WRAP_recv_dir = "";
 string WRAP_send_dir = "";
-string WRAP_auto_dir = "";
+//string WRAP_auto_dir = "";
 string ICS_dir = "";
 string ICS_msg_dir = "";
 string ICS_tmp_dir = "";
@@ -167,6 +179,7 @@ string CSV_dir = "";
 string CUSTOM_dir = "";
 string XFR_dir = "";
 string FLMSG_temp_dir = "";
+string FLMSG_log_dir = "";
 string FLMSG_custom_dir = "";
 
 string cmd_fname = "";
@@ -177,6 +190,13 @@ string evalstr = "";
 
 string parse_info = "";
 
+//======================================================================
+// custom edit/view only program use
+
+bool update_custom = false;
+
+//======================================================================
+
 //string defRTFname = "";
 
 // utility functions
@@ -192,6 +212,9 @@ static string szEdit = ":hdr_ed:";
 
 bool check_mycall()
 {
+	if (mainwindow == tyro_dialog)
+		return true;
+
 	if (!progStatus.my_call.empty())
 		return true;
 
@@ -540,23 +563,44 @@ char *szCAPDateTime()
 
 char *named_file()
 {
-	static char szfname[200];
+	static char szfname[400];
 	static char szDt[80];
 	szfname[0] = 0;
 	if (!progStatus.call_fname && !progStatus.dt_fname && !progStatus.sernbr_fname)
 		return szfname;
+
 	time_t tmptr;
 	tm sTime;
 	time (&tmptr);
-	gmtime_r (&tmptr, &sTime);
-	strftime(szDt, 79, "%Y%m%d-%H%M%SZ", &sTime);
-	szfname[0] = 0;
+	switch (progStatus.dt_fname) {
+		case 1 :
+			localtime_r (&tmptr, &sTime);
+			strftime(szDt, sizeof(szDt), "%Y%m%d-%H%M%SL", &sTime);
+			break;
+		case 2 :
+			localtime_r (&tmptr, &sTime);
+			strftime(szDt, sizeof(szDt), "%Y%m%d-%H%M%S%Z", &sTime);
+			break;
+		case 3 :
+			localtime_r (&tmptr, &sTime);
+			strftime(szDt, sizeof(szDt), "%Y%m%d-%H%M%S%z", &sTime);
+			break;
+		case 4 :
+			gmtime_r (&tmptr, &sTime);
+			strftime(szDt, sizeof(szDt), "%Y%m%d-%H%M%SZ", &sTime);
+			break;
+		case 0 :
+		default :
+			szDt[0] = 0;
+	}
+
 	if (progStatus.call_fname) strcat(szfname, progStatus.my_call.c_str());
+
 	if (selected_form == RADIOGRAM  && progStatus.rgnbr_fname) {
 		if (szfname[0]) strcat(szfname, "-");
 		strcat(szfname, progStatus.rgnbr.c_str());
 	} else {
-		if (progStatus.dt_fname) {
+		if (szDt[0]) {
 			if (szfname[0]) strcat(szfname, "-");
 			strcat(szfname, szDt);
 		}
@@ -568,9 +612,24 @@ char *named_file()
 	return szfname;
 }
 
+void update_sernbr ()
+{
+string dfname = FLMSG_dir;
+dfname.append("flmsg.sernbrs");
+FILE *debug_file = fl_fopen(dfname.c_str(), "a");
+	int n = atoi(progStatus.sernbr.c_str());
+	n++;
+	char szn[10];
+	snprintf(szn, sizeof(szn), "%d", n);
+	progStatus.sernbr = szn;
+	txt_sernbr->value(szn);
+	txt_sernbr->redraw();
+fprintf(debug_file, "New ser # %s\n" , szn);
+fclose(debug_file);
+}
+
 void extract_text(string &buffer, const char *fname)
 {
-	string sfname = fname;
 	remove_cr(buffer);
 
 	if (buffer.find("<radiogram>") != string::npos) {
@@ -613,11 +672,6 @@ void extract_text(string &buffer, const char *fname)
 		read_mars_army_buffer(buffer);
 		if (fname) def_mars_army_filename = fname;
 		select_form(selected_form);
-	} else if (buffer.find("<mars_navy>") != string::npos) {
-		selected_form = MARSNAVY;
-		read_mars_navy_buffer(buffer);
-		if (fname) def_mars_navy_filename = fname;
-		select_form(selected_form);
 	} else if (buffer.find("<nhc_wx>") != string::npos) {
 		selected_form = WXHC;
 		read_wxhc_buffer(buffer);
@@ -738,8 +792,16 @@ void extract_text(string &buffer, const char *fname)
 		read_custombuffer(buffer);
 		if (fname) def_custom_filename = fname;
 		select_form(selected_form);
-	} else if (!exit_after_print)
-		fl_alert2(_("Not an flmsg data file"));
+	} else if (!exit_after_print){
+extern string blank_field;
+extern void update_blankform();
+		selected_form = BLANK;
+		cb_blank_new();
+		if (fname) def_blank_filename = fname;
+		select_form(selected_form);
+		blank_field = buffer;
+		update_blankform();
+	}
 }
 
 //
@@ -806,7 +868,6 @@ int eval_transfer_size()
 		case MARSINEEI:	return eval_mars_ineei_fsize();
 		case MARSNET:	return eval_mars_net_fsize();
 		case MARSARMY:	return eval_mars_army_fsize();
-		case MARSNAVY:	return eval_mars_navy_fsize();
 		case WXHC:		return eval_wxhc_fsize();
 		case SEVEREWX:	return eval_severe_wx_fsize();
 		case STORMREP:	return eval_storm_fsize();
@@ -848,7 +909,6 @@ void cb_new()
 		case MARSINEEI: cb_mars_ineei_new(); break;
 		case MARSNET: cb_mars_net_new(); break;
 		case MARSARMY: cb_mars_army_new(); break;
-		case MARSNAVY: cb_mars_navy_new(); break;
 		case WXHC: cb_wxhc_new(); break;
 		case SEVEREWX: cb_severe_wx_new(); break;
 		case STORMREP: cb_storm_new(); break;
@@ -893,7 +953,6 @@ void cb_import()
 		case MARSINEEI:
 		case MARSNET:
 		case MARSARMY:
-		case MARSNAVY:
 		case WXHC:
 		case SEVEREWX:
 		case STORMREP:
@@ -935,7 +994,6 @@ void cb_export()
 		case MARSINEEI:
 		case MARSNET:
 		case MARSARMY:
-		case MARSNAVY:
 		case WXHC:
 		case SEVEREWX:
 		case STORMREP:
@@ -955,6 +1013,11 @@ void wrap_import(const char *fname)
 		isok = !fl_choice2(_("Checksum failed\n\nIgnore errors?"), "yes", "no", NULL);
 	}
 
+	if (inpbuffer.find("<transfer") != string::npos) {
+		save_this_file_as(filename, inpbuffer);
+		return;
+	}
+
 	if (isok) {
 		if (!(inpbuffer.find("<transfer>") != string::npos &&
 			inpbuffer.find("<html_file>") != string::npos) )
@@ -1036,9 +1099,6 @@ void wrap_import(const char *fname)
 			} else if (inpbuffer.find("<mars_army>") != string::npos) {
 				selected_form = MARSARMY;
 				cb_mars_army_wrap_import(filename, inpbuffer);
-			} else if (inpbuffer.find("<mars_navy>") != string::npos) {
-				selected_form = MARSNAVY;
-				cb_mars_navy_wrap_import(filename, inpbuffer);
 			} else if (inpbuffer.find("<nhc_wx>") != string::npos) {
 				selected_form = WXHC;
 				cb_wxhc_wrap_import(filename, inpbuffer);
@@ -1128,7 +1188,7 @@ void wrap_import(const char *fname)
 void cb_wrap_import()
 {
 	string wrapfilename = WRAP_recv_dir;
-	wrapfilename.append("default"WRAP_EXT);
+	wrapfilename.append("default").append(WRAP_EXT);
 	const char *p = FSEL::select(
 		"Import wrapped flmsg file",
 		"Wrap file\t*.{wrap,WRAP}",
@@ -1161,12 +1221,11 @@ void cb_wrap_export()
 		case BLANK: cb_blank_wrap_export(); break;
 		case CSV: cb_csv_wrap_export(); break;
 		case CUSTOM: cb_custom_wrap_export(); break;
-		case TRANSFER: cb_transfer_wrap_export(); break;
+		case TRANSFER: break;//cb_transfer_wrap_export(); break;
 		case MARSDAILY: cb_mars_daily_wrap_export(); break;
 		case MARSINEEI: cb_mars_ineei_wrap_export(); break;
 		case MARSNET: cb_mars_net_wrap_export(); break;
 		case MARSARMY: cb_mars_army_wrap_export(); break;
-		case MARSNAVY: cb_mars_navy_wrap_export(); break;
 		case WXHC: cb_wxhc_wrap_export(); break;
 		case SEVEREWX: cb_severe_wx_wrap_export(); break;
 		case STORMREP: cb_storm_wrap_export(); break;
@@ -1219,7 +1278,6 @@ void cb_wrap_autosend()
 		case MARSINEEI: cb_mars_ineei_wrap_autosend(); break;
 		case MARSNET: cb_mars_net_wrap_autosend(); break;
 		case MARSARMY: cb_mars_army_wrap_autosend(); break;
-		case MARSNAVY: cb_mars_navy_wrap_autosend(); break;
 		case WXHC: cb_wxhc_wrap_autosend(); break;
 		case SEVEREWX: cb_severe_wx_wrap_autosend(); break;
 		case STORMREP: cb_storm_wrap_autosend(); break;
@@ -1259,7 +1317,6 @@ void cb_load_template()
 		case MARSINEEI: cb_mars_ineei_load_template(); break;
 		case MARSNET: cb_mars_net_load_template(); break;
 		case MARSARMY: cb_mars_army_load_template(); break;
-		case MARSNAVY: cb_mars_navy_load_template(); break;
 		case WXHC: cb_wxhc_load_template(); break;
 		case SEVEREWX: cb_severe_wx_load_template(); break;
 		case STORMREP: cb_storm_load_template(); break;
@@ -1300,7 +1357,6 @@ void cb_save_template()
 		case MARSINEEI: cb_mars_ineei_save_template(); break;
 		case MARSNET: cb_mars_net_save_template(); break;
 		case MARSARMY: cb_mars_army_save_template(); break;
-		case MARSNAVY: cb_mars_navy_save_template(); break;
 		case WXHC: cb_wxhc_save_template(); break;
 		case SEVEREWX: cb_severe_wx_save_template(); break;
 		case STORMREP: cb_storm_save_template(); break;
@@ -1340,7 +1396,6 @@ void cb_save_as_template()
 		case MARSINEEI: cb_mars_ineei_save_as_template(); break;
 		case MARSNET: cb_mars_net_save_as_template(); break;
 		case MARSARMY: cb_mars_army_save_as_template(); break;
-		case MARSNAVY: cb_mars_navy_save_as_template(); break;
 		case WXHC: cb_wxhc_save_as_template(); break;
 		case SEVEREWX: cb_severe_wx_save_as_template(); break;
 		case STORMREP: cb_storm_save_as_template(); break;
@@ -1380,7 +1435,6 @@ void cb_open()
 		case MARSINEEI: cb_mars_ineei_open(); break;
 		case MARSNET: cb_mars_net_open(); break;
 		case MARSARMY: cb_mars_army_open(); break;
-		case MARSNAVY: cb_mars_navy_open(); break;
 		case WXHC: cb_wxhc_open(); break;
 		case SEVEREWX: cb_severe_wx_open(); break;
 		case STORMREP: cb_storm_open(); break;
@@ -1417,7 +1471,6 @@ void cb_save_as()
 		case MARSINEEI: cb_mars_ineei_save_as(); break;
 		case MARSNET: cb_mars_net_save_as(); break;
 		case MARSARMY: cb_mars_army_save_as(); break;
-		case MARSNAVY: cb_mars_navy_save_as(); break;
 		case WXHC: cb_wxhc_save_as(); break;
 		case SEVEREWX: cb_severe_wx_save_as(); break;
 		case STORMREP: cb_storm_save_as(); break;
@@ -1457,7 +1510,6 @@ void cb_save()
 		case MARSINEEI: cb_mars_ineei_save(); break;
 		case MARSNET: cb_mars_net_save(); break;
 		case MARSARMY: cb_mars_army_save(); break;
-		case MARSNAVY: cb_mars_navy_save(); break;
 		case WXHC: cb_wxhc_save(); break;
 		case SEVEREWX: cb_severe_wx_save(); break;
 		case STORMREP: cb_storm_save(); break;
@@ -1497,7 +1549,6 @@ void cb_html()
 		case MARSINEEI: cb_mars_ineei_html(); break;
 		case MARSNET: cb_mars_net_html(); break;
 		case MARSARMY: cb_mars_army_html(); break;
-		case MARSNAVY: cb_mars_navy_html(); break;
 		case WXHC: cb_wxhc_html(); break;
 		case SEVEREWX: cb_severe_wx_html(); break;
 		case STORMREP: cb_storm_html(); break;
@@ -1559,7 +1610,6 @@ void cb_text()
 		case MARSINEEI: cb_mars_ineei_textout(); break;
 		case MARSNET: cb_mars_net_textout(); break;
 		case MARSARMY: cb_mars_army_textout(); break;
-		case MARSNAVY: cb_mars_navy_textout(); break;
 		case WXHC: cb_wxhc_textout(); break;
 		case SEVEREWX: cb_severe_wx_textout(); break;
 		case STORMREP: cb_storm_textout(); break;
@@ -1574,20 +1624,25 @@ void cb_text()
 	}
 }
 
-extern void disconnect_from_fldigi();
+//extern void disconnect_from_fldigi();
 
 void cb_exit()
 {
 	progStatus.saveLastState();
 	FSEL::destroy();
-	try {
-		disconnect_from_fldigi();
-	}
-	catch (...) {
-	}
+
+	Fl::remove_timeout(mainloop);
+
+	if (progStatus.ID_restore) restore_id();
+
 	close_xmlrpc();
 	close_server();
+
 	debug::stop();
+
+	if (expert_dialog) delete expert_dialog;
+	if (tyro_dialog) delete tyro_dialog;
+
 	exit(0);
 }
 
@@ -1600,7 +1655,9 @@ void exit_main(Fl_Widget *w)
 
 void cb_About()
 {
-	fl_alert2(_("Version "PACKAGE_VERSION));
+	std::string strver = _("Version ");
+	strver.append(PACKAGE_VERSION);
+	fl_alert2("%s", strver.c_str());
 }
 
 void cb_folders()
@@ -1677,9 +1734,6 @@ void show_filename(string p)
 		case MARSARMY:
 			base_mars_army_filename = fl_filename_name(p.c_str());
 			break;
-		case MARSNAVY:
-			base_mars_navy_filename = fl_filename_name(p.c_str());
-			break;
 		case WXHC:
 			base_wxhc_filename = fl_filename_name(p.c_str());
 			break;
@@ -1787,192 +1841,188 @@ void after_start(void *)
 	check_mycall();
 
 	def_203_filename = ICS_msg_dir;
-	def_203_filename.append("default"F203_EXT);
+	def_203_filename.append("default").append(F203_EXT);
 	def_203_TemplateName = ICS_tmp_dir;
-	def_203_TemplateName.append("default"T203_EXT);
+	def_203_TemplateName.append("default").append(T203_EXT);
 
 	def_205_filename = ICS_msg_dir;
-	def_205_filename.append("default"F205_EXT);
+	def_205_filename.append("default").append(F205_EXT);
 	def_205_TemplateName = ICS_tmp_dir;
-	def_205_TemplateName.append("default"T205_EXT);
+	def_205_TemplateName.append("default").append(T205_EXT);
 
 	def_205a_filename = ICS_msg_dir;
-	def_205a_filename.append("default"F205A_EXT);
+	def_205a_filename.append("default").append(F205A_EXT);
 	def_205a_TemplateName = ICS_tmp_dir;
-	def_205a_TemplateName.append("default"T205A_EXT);
+	def_205a_TemplateName.append("default").append(T205A_EXT);
 
 	def_206_filename = ICS_msg_dir;
-	def_206_filename.append("default"F206_EXT);
+	def_206_filename.append("default").append(F206_EXT);
 	def_206_TemplateName = ICS_tmp_dir;
-	def_206_TemplateName.append("default"T206_EXT);
+	def_206_TemplateName.append("default").append(T206_EXT);
 
 	def_213_filename = ICS_msg_dir;
-	def_213_filename.append("default"F213_EXT);
+	def_213_filename.append("default").append(F213_EXT);
 	def_213_TemplateName = ICS_tmp_dir;
-	def_213_TemplateName.append("default"T213_EXT);
+	def_213_TemplateName.append("default").append(T213_EXT);
 
 	def_214_filename = ICS_msg_dir;
-	def_214_filename.append("default"F214_EXT);
+	def_214_filename.append("default").append(F214_EXT);
 	def_214_TemplateName = ICS_tmp_dir;
-	def_214_TemplateName.append("default"T214_EXT);
+	def_214_TemplateName.append("default").append(T214_EXT);
 
 	def_216_filename = ICS_msg_dir;
-	def_216_filename.append("default"F216_EXT);
+	def_216_filename.append("default").append(F216_EXT);
 	def_216_TemplateName = ICS_tmp_dir;
-	def_216_TemplateName.append("default"T216_EXT);
+	def_216_TemplateName.append("default").append(T216_EXT);
 
 	def_309_filename = ICS_msg_dir;
-	def_309_filename.append("default"F309_EXT);
+	def_309_filename.append("default").append(F309_EXT);
 	def_309_TemplateName = ICS_tmp_dir;
-	def_309_TemplateName.append("default"T309_EXT);
+	def_309_TemplateName.append("default").append(T309_EXT);
 
 	def_netlog_filename = ICS_msg_dir;
-	def_netlog_filename.append("default"FNET_EXT);
+	def_netlog_filename.append("default").append(FNET_EXT);
 	def_netlog_TemplateName = ICS_tmp_dir;
-	def_netlog_TemplateName.append("default"TNET_EXT);
+	def_netlog_TemplateName.append("default").append(TNET_EXT);
 
 	def_hics203_filename = ICS_msg_dir;
-	def_hics203_filename.append("default"HF203_EXT);
+	def_hics203_filename.append("default").append(HF203_EXT);
 	def_hics203_TemplateName = ICS_tmp_dir;
-	def_hics203_TemplateName.append("default"HT203_EXT);
+	def_hics203_TemplateName.append("default").append(HT203_EXT);
 
 	h206_def_filename = ICS_msg_dir;
-	h206_def_filename.append("default"HF206_EXT);
+	h206_def_filename.append("default").append(HF206_EXT);
 	h206_def_template_name = ICS_tmp_dir;
-	h206_def_template_name.append("default"HT206_EXT);
+	h206_def_template_name.append("default").append(HT206_EXT);
 
 	h213_def_filename = ICS_msg_dir;
-	h213_def_filename.append("default"HF213_EXT);
+	h213_def_filename.append("default").append(HF213_EXT);
 	h213_def_template_name = ICS_tmp_dir;
-	h213_def_template_name.append("default"HT213_EXT);
+	h213_def_template_name.append("default").append(HT213_EXT);
 
 	hics214_def_filename = ICS_msg_dir;
-	hics214_def_filename.append("default"HF214_EXT);
+	hics214_def_filename.append("default").append(HF214_EXT);
 	hics214_template_name = ICS_tmp_dir;
-	hics214_template_name.append("default"HT214_EXT);
+	hics214_template_name.append("default").append(HT214_EXT);
 
 	def_rg_filename = ICS_msg_dir;
-	def_rg_filename.append("default"RGFILE_EXT);
+	def_rg_filename.append("default").append(RGFILE_EXT);
 	def_rg_TemplateName = ICS_tmp_dir;
-	def_rg_TemplateName.append("default"RGTEMP_EXT);
+	def_rg_TemplateName.append("default").append(RGTEMP_EXT);
 
 	iaru_def_filename = ICS_msg_dir;
-	iaru_def_filename.append("default"IARU_FILE_EXT);
+	iaru_def_filename.append("default").append(IARU_FILE_EXT);
 	iaru_def_template_name = ICS_tmp_dir;
-	iaru_def_template_name.append("default"IARU_TEMP_EXT);
+	iaru_def_template_name.append("default").append(IARU_TEMP_EXT);
 
 	cap105_def_filename = ICS_msg_dir;
-	cap105_def_filename.append("default"CAP105_FILE_EXT);
+	cap105_def_filename.append("default").append(CAP105_FILE_EXT);
 	cap105_def_template_name = ICS_tmp_dir;
-	cap105_def_template_name.append("default"CAP105_TEMP_EXT);
+	cap105_def_template_name.append("default").append(CAP105_TEMP_EXT);
 	cap105_set_choices();
 
 	cap110_def_filename = ICS_msg_dir;
-	cap110_def_filename.append("default"CAP105_FILE_EXT);
+	cap110_def_filename.append("default").append(CAP105_FILE_EXT);
 	cap110_def_template_name = ICS_tmp_dir;
-	cap110_def_template_name.append("default"CAP105_TEMP_EXT);
+	cap110_def_template_name.append("default").append(CAP105_TEMP_EXT);
 
 	def_pt_filename = ICS_msg_dir;
-	def_pt_filename.append("default"PTFILE_EXT);
+	def_pt_filename.append("default").append(PTFILE_EXT);
 	def_pt_TemplateName = ICS_tmp_dir;
-	def_pt_TemplateName.append("default"PTTEMP_EXT);
+	def_pt_TemplateName.append("default").append(PTTEMP_EXT);
 
 	def_blank_filename = ICS_msg_dir;
-	def_blank_filename.append("default"BLANKFILE_EXT);
+	def_blank_filename.append("default").append(BLANKFILE_EXT);
 	def_blank_TemplateName = ICS_tmp_dir;
-	def_blank_TemplateName.append("default"BLANKTEMP_EXT);
+	def_blank_TemplateName.append("default").append(BLANKTEMP_EXT);
 
 	def_csv_filename = ICS_msg_dir;
-	def_csv_filename.append("default"CSVFILE_EXT);
+	def_csv_filename.append("default").append(CSVFILE_EXT);
 	def_csv_TemplateName = ICS_tmp_dir;
-	def_csv_TemplateName.append("default"CSVTEMP_EXT);
+	def_csv_TemplateName.append("default").append(CSVTEMP_EXT);
 
 	def_custom_filename = ICS_msg_dir;
-	def_custom_filename.append("default"CUSTOMFILE_EXT);
+	def_custom_filename.append("default").append(CUSTOMFILE_EXT);
 	def_custom_TemplateName = ICS_tmp_dir;
-	def_custom_TemplateName.append("default"CUSTOMTEMP_EXT);
+	def_custom_TemplateName.append("default").append(CUSTOMTEMP_EXT);
 
 	def_mars_daily_filename = ICS_msg_dir;
-	def_mars_daily_filename.append("default"FMARSDAILY_EXT);
+	def_mars_daily_filename.append("default").append(FMARSDAILY_EXT);
 	def_mars_daily_TemplateName = ICS_tmp_dir;
-	def_mars_daily_TemplateName.append("default"TMARSDAILY_EXT);
+	def_mars_daily_TemplateName.append("default").append(TMARSDAILY_EXT);
 
 	def_mars_ineei_filename = ICS_msg_dir;
-	def_mars_ineei_filename.append("default"FMARSINEEI_EXT);
+	def_mars_ineei_filename.append("default").append(FMARSINEEI_EXT);
 	def_mars_ineei_TemplateName = ICS_tmp_dir;
-	def_mars_ineei_TemplateName.append("default"TMARSINEEI_EXT);
+	def_mars_ineei_TemplateName.append("default").append(TMARSINEEI_EXT);
 
 	def_mars_net_filename = ICS_msg_dir;
-	def_mars_net_filename.append("default"FMARSNET_EXT);
+	def_mars_net_filename.append("default").append(FMARSNET_EXT);
 	def_mars_net_TemplateName = ICS_tmp_dir;
-	def_mars_net_TemplateName.append("default"TMARSNET_EXT);
+	def_mars_net_TemplateName.append("default").append(TMARSNET_EXT);
 
 	def_mars_army_filename = ICS_msg_dir;
-	def_mars_army_filename.append("default"FMARSARMY_EXT);
+	def_mars_army_filename.append("default").append(FMARSARMY_EXT);
 	def_mars_army_TemplateName = ICS_tmp_dir;
-	def_mars_army_TemplateName.append("default"TMARSARMY_EXT);
-
-	def_mars_navy_filename = ICS_msg_dir;
-	def_mars_navy_filename.append("default"FMARSNAVY_EXT);
-	def_mars_navy_TemplateName = ICS_tmp_dir;
-	def_mars_navy_TemplateName.append("default"TMARSNAVY_EXT);
+	def_mars_army_TemplateName.append("default").append(TMARSARMY_EXT);
 
 	def_wxhc_filename = ICS_msg_dir;
-	def_wxhc_filename.append("default"FWXHC_EXT);
+	def_wxhc_filename.append("default").append(FWXHC_EXT);
 	def_wxhc_TemplateName = ICS_tmp_dir;
-	def_wxhc_TemplateName.append("default"TWXHC_EXT);
+	def_wxhc_TemplateName.append("default").append(TWXHC_EXT);
 
 	def_severe_wx_filename = ICS_msg_dir;
-	def_severe_wx_filename.append("default"FSWX_EXT);
+	def_severe_wx_filename.append("default").append(FSWX_EXT);
 	def_severe_wx_TemplateName = ICS_tmp_dir;
-	def_severe_wx_TemplateName.append("default"TSWX_EXT);
+	def_severe_wx_TemplateName.append("default").append(TSWX_EXT);
 
 	def_storm_filename = ICS_msg_dir;
-	def_storm_filename.append("default"FSTRM_EXT);
+	def_storm_filename.append("default").append(FSTRM_EXT);
 	def_storm_TemplateName = ICS_tmp_dir;
-	def_storm_TemplateName.append("default"TSTRM_EXT);
+	def_storm_TemplateName.append("default").append(TSTRM_EXT);
 
 	def_redx_snw_filename = ICS_msg_dir;
-	def_redx_snw_filename.append("default"FREDXSNW_EXT);
+	def_redx_snw_filename.append("default").append(FREDXSNW_EXT);
 	def_redx_snw_TemplateName = ICS_tmp_dir;
-	def_redx_snw_TemplateName.append("default"TREDXSNW_EXT);
+	def_redx_snw_TemplateName.append("default").append(TREDXSNW_EXT);
 
 	def_redx_5739_filename = ICS_msg_dir;
-	def_redx_5739_filename.append("default"FREDX5739_EXT);
+	def_redx_5739_filename.append("default").append(FREDX5739_EXT);
 	def_redx_5739_TemplateName = ICS_tmp_dir;
-	def_redx_5739_TemplateName.append("default"TREDX5739_EXT);
+	def_redx_5739_TemplateName.append("default").append(TREDX5739_EXT);
 
 	def_redx_5739A_filename = ICS_msg_dir;
-	def_redx_5739A_filename.append("default"FREDX5739A_EXT);
+	def_redx_5739A_filename.append("default").append(FREDX5739A_EXT);
 	def_redx_5739A_TemplateName = ICS_tmp_dir;
-	def_redx_5739A_TemplateName.append("default"TREDX5739A_EXT);
+	def_redx_5739A_TemplateName.append("default").append(TREDX5739A_EXT);
 
 	def_redx_5739B_filename = ICS_msg_dir;
-	def_redx_5739B_filename.append("default"FREDX5739B_EXT);
+	def_redx_5739B_filename.append("default").append(FREDX5739B_EXT);
 	def_redx_5739B_TemplateName = ICS_tmp_dir;
-	def_redx_5739B_TemplateName.append("default"TREDX5739B_EXT);
-
-	if (!cmd_fname.empty()) {
-		if (cmd_fname.find(WRAP_EXT) != string::npos)
-			wrap_import(cmd_fname.c_str());
-		else {
-			read_data_file(cmd_fname);
-			show_filename(cmd_fname);
-		}
-		estimate();
-	} else
-		default_form();
+	def_redx_5739B_TemplateName.append("default").append(TREDX5739B_EXT);
 
+	{
+		if (!cmd_fname.empty()) {
+			if (cmd_fname.find(WRAP_EXT) != string::npos)
+				wrap_import(cmd_fname.c_str());
+			else {
+				read_data_file(cmd_fname);
+				show_filename(cmd_fname);
+			}
+			estimate();
+		} else
+			default_form();
 	// Check to see what io mode FLDIGI is in.
-	std::string io_mode = get_io_mode();
-	int flag = 0;
-	if(!io_mode.empty()) {
-		flag = strncmp(io_mode.c_str(), "ARQ", 3);
-		if(flag != 0) {
-			flag = fl_choice2(_("KISS interface active! Switch FLDIGI to ARQ?"),
-			   _("No"), _("Yes"), NULL);
-			if(flag == 1)
-				enable_arq();
+		std::string io_mode = get_io_mode();
+		int flag = 0;
+		if(!io_mode.empty()) {
+			flag = strncmp(io_mode.c_str(), "ARQ", 3);
+			if(flag != 0) {
+				flag = fl_choice2(_("KISS interface active! Switch FLDIGI to ARQ?"),
+					_("No"), _("Yes"), NULL);
+				if(flag == 1)
+					enable_arq();
+			}
 		}
 	}
 
@@ -1980,11 +2030,8 @@ void after_start(void *)
 	fl_open_callback(open_callback);
 #endif
 
-	try {
-		connect_to_fldigi();
-	}
-	catch (...) {
-	}
+	init_flmsg_arq();
+
 }
 
 int main(int argc, char *argv[])
@@ -1999,7 +2046,7 @@ int main(int argc, char *argv[])
 			return 0;
 		}
 		if (strcasecmp("--version", argv[1]) == 0) {
-			printf("Version: "VERSION"\n");
+			printf("Version: %s\n", VERSION);
 			return 0;
 		}
 	}
@@ -2015,59 +2062,63 @@ int main(int argc, char *argv[])
 	if (Fl::args(argc, argv, arg_idx, parse_args) != argc)
 		showoptions();
 
-	{
-		size_t p;
-		string appdir;
-		char dirbuf[FL_PATH_MAX + 1];
+	size_t p;
+	string appdir = argv[0];;
 
 #ifdef __WOE32__
-		fl_filename_expand(dirbuf, FL_PATH_MAX, argv[0]);
-		appdir.assign(dirbuf);
-		p = appdir.rfind("flmsg.exe");
-		if (p != string::npos)
-			appdir.erase(p);
-		p = appdir.find("FL_APPS/");
+	if (FLMSG_dir.empty()) {
+		p = appdir.find("FL_APPS\\");
+		if (p == string::npos)
+			p = appdir.find("FL_APPS/");
 		if (p != string::npos) {
 			FLMSG_dir.assign(appdir.substr(0, p + 8));
 			FLMSG_dir.append("NBEMS.files/");
-		} else if (FLMSG_dir.empty()) {
-			fl_filename_expand(dirbuf, FL_PATH_MAX, "$USERPROFILE/");
+		} else {
+			char dirbuf[FL_PATH_MAX + 1];
+			fl_filename_expand(dirbuf, sizeof(dirbuf) -1, "$USERPROFILE/");
 			FLMSG_dir.assign(dirbuf);
 			FLMSG_dir.append("NBEMS.files/");
 		}
-#else
-		fl_filename_absolute(dirbuf, FL_PATH_MAX, argv[0]);
-		appdir.assign(dirbuf);
-		p = appdir.rfind("flmsg");
-		if (p != string::npos)
-			appdir.erase(p);
-		p = appdir.find("FL_APPS/");
-		if (p != string::npos) {
-			FLMSG_dir.assign(appdir.substr(0, p + 8));
-			FLMSG_dir.append("NBEMS.files/");
-		} else if (FLMSG_dir.empty()) {
-			fl_filename_expand(dirbuf, FL_PATH_MAX, "$HOME/");
-			FLMSG_dir = dirbuf;
-			FLMSG_dir.append(".nbems/");
-		}
-/*
-		DIR *isdir = 0;
-		string test_dir;
-		test_dir.assign(FLMSG_dir);
-		isdir = opendir(test_dir.c_str());
-		if (isdir) {
-			FLMSG_dir = test_dir;
-			closedir(isdir);
-		} else {
-			FLMSG_dir.append(".nbems/");
-		}
-*/
-#endif
 	}
+#else
+	char dirbuf[FL_PATH_MAX + 1];
+	fl_filename_absolute(dirbuf, FL_PATH_MAX, argv[0]);
+	appdir.assign(dirbuf);
+	p = appdir.rfind("flmsg");
+	if (p != string::npos)
+		appdir.erase(p);
+	p = appdir.find("FL_APPS/");
+	if (p == string::npos) p = appdir.find("ARC_MSG/");
+	if (p != string::npos) {
+		FLMSG_dir.assign(appdir.substr(0, p + 8));
+		FLMSG_dir.append("NBEMS.files/");
+	} else if (FLMSG_dir.empty()) {
+		fl_filename_expand(dirbuf, FL_PATH_MAX, "$HOME/");
+		FLMSG_dir = dirbuf;
+		FLMSG_dir.append(".nbems/");
+	}
+#endif
 
 	progStatus.loadLastState();
 
-	mainwindow = flmsg_dialog();
+	expert_dialog = flmsg_dialog();
+	tyro_dialog = edit_view_dialog();
+
+	if (!progStatus.UI_default) {
+		int answer = fl_choice(
+			"FLMSG: Select Default User Interface\n\n\n",
+			"Communicator / Expert",
+			"Service Agency / Simple",
+			NULL );
+		progStatus.UI_default = 1;
+		progStatus.UI_expert = !answer;
+	}
+
+	if (progStatus.UI_expert)
+		mainwindow = expert_dialog;
+	else
+		mainwindow = tyro_dialog;
+
 	mainwindow->callback(exit_main);
 	set_rg_choices();
 	iaru_set_choices();
@@ -2099,6 +2150,11 @@ int main(int argc, char *argv[])
 	FSEL::create();
 
 	checkdirectories();
+
+	string logname = FLMSG_log_dir;
+	logname.append("flmsg.log");
+	rotate_log(logname);
+
 	load_custom_menu();
 
 	string debug_file = FLMSG_dir;
@@ -2113,7 +2169,7 @@ int main(int argc, char *argv[])
 	LOG_INFO("WRAP_dir         %s", WRAP_dir.c_str());
 	LOG_INFO("WRAP_recv_dir    %s", WRAP_recv_dir.c_str());
 	LOG_INFO("WRAP_send_dir    %s", WRAP_send_dir.c_str());
-	LOG_INFO("WRAP_auto_dir    %s", WRAP_auto_dir.c_str());
+//	LOG_INFO("WRAP_auto_dir    %s", WRAP_auto_dir.c_str());
 	LOG_INFO("ICS_dir          %s", ICS_dir.c_str());
 	LOG_INFO("ICS_msg_dir      %s", ICS_msg_dir.c_str());
 	LOG_INFO("ICS_tmp_dir      %s", ICS_tmp_dir.c_str());
@@ -2121,6 +2177,7 @@ int main(int argc, char *argv[])
 	LOG_INFO("CUSTOM_dir       %s", CUSTOM_dir.c_str());
 	LOG_INFO("Transfer dir     %s", XFR_dir.c_str());
 	LOG_INFO("FLMSG_temp_dir   %s", FLMSG_temp_dir.c_str());
+	LOG_INFO("FLMSG_log_dir    %s", FLMSG_log_dir.c_str());
 
 	if (!parse_info.empty())
 		LOG_INFO("%s", parse_info.c_str());
@@ -2135,8 +2192,10 @@ int main(int argc, char *argv[])
 		fl_open_display();
 #endif
 		print_and_exit();
-		if (exit_after_print)
+		if (exit_after_print) {
+			if (server) mg_destroy_server(&server);
 			return 0;
+		}
 	}
 
 	open_xmlrpc();
@@ -2146,8 +2205,10 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
-	mainwindow->resize( progStatus.mainX, progStatus.mainY, mainwindow->w(), mainwindow->h());
+	expert_dialog->resize( progStatus.mainX, progStatus.mainY, expert_dialog->w(), expert_dialog->h());
 
+	tyro_dialog->resize( progStatus.mainX, progStatus.mainY, tyro_dialog->w(), tyro_dialog->h());
+	
 #if defined(__WOE32__)
 #  ifndef IDI_ICON
 #    define IDI_ICON 101
@@ -2162,11 +2223,12 @@ int main(int argc, char *argv[])
 	mainwindow->show(argc, argv);
 #endif
 
-	if (string(mainwindow->label()) == "") {
-		string main_label = PACKAGE_NAME;
-		main_label.append(": ").append(PACKAGE_VERSION);
-		mainwindow->label(main_label.c_str());
-	}
+	ARQdropdown(progStatus.arq_shown);
+
+	string main_label = PACKAGE_NAME;
+	main_label.append(": ").append(PACKAGE_VERSION);
+	expert_dialog->label(main_label.c_str());
+	tyro_dialog->label(main_label.c_str());
 
 	Fl::add_timeout(0.10, after_start);
 
@@ -2180,7 +2242,6 @@ int main(int argc, char *argv[])
 void print_and_exit()
 {
 	if (!cmd_fname.empty()) {
-
 		if (cmd_fname.find(WRAP_EXT) != string::npos) {
 			wrap_import(cmd_fname.c_str());
 		} else {
@@ -2276,10 +2337,6 @@ void print_and_exit()
 			cb_mars_army_save();
 			cb_mars_army_html();
 			break;
-		case MARSNAVY :
-			cb_mars_navy_save();
-			cb_mars_navy_html();
-			break;
 		case WXHC :
 			cb_wxhc_save();
 			cb_wxhc_html();
@@ -2372,14 +2429,15 @@ void checkdirectories(void)
 		{ WRAP_dir,       "WRAP", 0 },
 		{ WRAP_recv_dir,  "WRAP/recv", 0 },
 		{ WRAP_send_dir,  "WRAP/send", 0 },
-		{ WRAP_auto_dir,  "WRAP/auto", 0 },
+//		{ WRAP_auto_dir,  "WRAP/auto", 0 },
 		{ ICS_dir,        "ICS", 0 },
 		{ ICS_msg_dir,    "ICS/messages", 0 },
 		{ ICS_tmp_dir,    "ICS/templates", 0 },
 		{ CSV_dir,        "CSV", 0},
 		{ CUSTOM_dir,     "CUSTOM", 0},
 		{ XFR_dir,        "TRANSFERS", 0},
-		{ FLMSG_temp_dir, "temp_files", 0 }
+		{ FLMSG_temp_dir, "temp_files", 0 },
+		{ FLMSG_log_dir,  "log_files", 0 }
 	};
 
 	int r;
@@ -2444,14 +2502,13 @@ void set_config_values()
 	txt_sernbr->value(progStatus.sernbr.c_str());
 	btn_sernbr_fname->value(progStatus.sernbr_fname);
 	btn_call_fname->value(progStatus.call_fname);
-	btn_dt_fname->value(progStatus.dt_fname);
+	cbo_dt_fname->index(progStatus.dt_fname);
 
 	txt_mars_roster_file->value(progStatus.mars_roster_file.c_str());
 
-	txt_socket_addr->value(progStatus.socket_addr.c_str());
-	txt_socket_port->value(progStatus.socket_port.c_str());
+	txt_socket_addr->value(progStatus.xmlrpc_addr.c_str());
+	txt_socket_port->value(progStatus.xmlrpc_port.c_str());
 
-	txt_web_port->value(sz_srvr_portnbr);
 }
 
 void cb_config_date_time()
@@ -2482,10 +2539,24 @@ void cb_config_files()
 	config_dialog->show();
 }
 
-void cb_config_socket()
+//void cb_config_socket()
+//{
+//	set_config_values();
+//	tabs_config->value(tab_socket);
+//	config_dialog->show();
+//}
+
+void cb_config_arq()
 {
 	set_config_values();
-	tabs_config->value(tab_socket);
+	tabs_config->value(tab_arq);
+	config_dialog->show();
+}
+
+void cb_config_UI()
+{
+	set_config_values();
+	tabs_config->value(tab_UI);
 	config_dialog->show();
 }
 
@@ -2501,6 +2572,13 @@ void custom_download()
 
 int parse_args(int argc, char **argv, int& idx)
 {
+//	if (strstr(argv[idx], "--editor")) {
+//		flmsg_editor = true;
+//		idx++;
+//		parse_info.append("parsed --viewer\n");
+//		return 1;
+//	}
+
 	if (strstr(argv[idx], "--p")) {
 		printme = true;
 		exit_after_print = true;
@@ -2540,7 +2618,7 @@ int parse_args(int argc, char **argv, int& idx)
 		idx++;
 		return 2;
 	}
-
+/*
 	if (strstr(argv[idx], "--auto-dir")) {
 		idx++;
 		string tmp = argv[idx];
@@ -2553,9 +2631,10 @@ int parse_args(int argc, char **argv, int& idx)
 		idx++;
 		return 2;
 	}
-
-	if ( argv[idx][0] == '-' )
+*/
+	if ( argv[idx][0] == '-' ) {
 		return 0;
+	}
 
 	parse_info.append("parsed filename: ").append(argv[idx]).append("\n");
 
@@ -2629,9 +2708,6 @@ int parse_args(int argc, char **argv, int& idx)
 		fname.find(FMARSARMY_EXT) != string::npos ||
 		fname.find(TMARSARMY_EXT) != string::npos ||
 
-		fname.find(FMARSNAVY_EXT) != string::npos ||
-		fname.find(TMARSNAVY_EXT) != string::npos ||
-
 		fname.find(FWXHC_EXT) != string::npos ||
 		fname.find(TWXHC_EXT) != string::npos ||
 
@@ -2744,25 +2820,26 @@ static const char *html_waiting =
 	Custom form not posted<br>\n\
 	</html>";
 
-void load_custom(void *)
-{
-	load_custom_menu();
-}
+//void load_custom(void *)
+//{
+//	load_custom_menu();
+//}
 
 void * poll_server(void *d)
 {
-	int n = 10;
+//	int n = 10;
 	exit_server = false;
 
 	while(!exit_server) {
 		pthread_mutex_lock(&mutex_web_server);
 			mg_poll_server(server, 200);
 		pthread_mutex_unlock(&mutex_web_server);
-		n--;
-		if (!n) {
-			Fl::awake(load_custom, 0);
-			n = 100;
-		}
+//		n--;
+//		if (!n) {
+//			if (!progStatus.UI_expert) //flmsg_editor)
+//				Fl::awake(load_custom, 0);
+//			n = 30;
+//		}
 		MilliSleep(10);
 	}
 	return NULL;
@@ -2776,12 +2853,19 @@ void close_server()
 	MilliSleep(200);
 }
 
+void update_form(void *)
+{
+	cb_custom_save_as();
+	update_custom = false;
+}
+
 extern void get_html_vars(struct mg_connection *conn);
 static int web_handler(struct mg_connection *conn)
 {
 	if (strcmp(conn->uri, "/handle_post_request") == 0) {
 		get_html_vars(conn);
 		custom_viewer(conn);
+		if (update_custom) Fl::awake(update_form);
 	} else {
 		if (handle_type == HANDLE_EDIT) {
 			custom_editor(conn);
@@ -2856,4 +2940,24 @@ Range %d - %d", srvr_portnbr, last_portnbr - 1);
     return 1;
 }
 
+void rotate_log(std::string filename)
+{
+	const int n = 5; // rename existing log files to keep up to 5 old versions
+	ostringstream oldfn, newfn;
+	ostringstream::streampos p;
+
+	oldfn << filename << '.';
+	newfn << filename << '.';
+	p = oldfn.tellp();
+
+	for (int i = n - 1; i > 0; i--) {
+		oldfn.seekp(p);
+		newfn.seekp(p);
+		oldfn << i;
+		newfn << i + 1;
+		rename(oldfn.str().c_str(), newfn.str().c_str());
+	}
+	rename(filename.c_str(), oldfn.str().c_str());
+}
+
 
