@@ -325,7 +325,7 @@ void iaru_cb_new()
 	iaru_clear_form();
 	clear_header();
 	iaru_def_filename = ICS_msg_dir;
-	iaru_def_filename.append("new"IARU_FILE_EXT);
+	iaru_def_filename.append("new").append(IARU_FILE_EXT);
 	iaru_using_template = false;
 	show_filename(iaru_def_filename);
 }
@@ -375,7 +375,8 @@ void iaru_cb_wrap_export()
 	}
 	iaru_update_fields();
 
-	if (iaru_base_filename == "new"IARU_FILE_EXT || iaru_base_filename == "default"IARU_FILE_EXT)
+	if (iaru_base_filename == string("new").append(IARU_FILE_EXT) ||
+		iaru_base_filename == string("default").append(IARU_FILE_EXT) )
 		if (!iaru_cb_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
@@ -409,7 +410,8 @@ void iaru_cb_wrap_autosend()
 	}
 	iaru_update_fields();
 
-	if (iaru_base_filename == "new"IARU_FILE_EXT || iaru_base_filename == "default"IARU_FILE_EXT)
+	if (iaru_base_filename == string("new").append(IARU_FILE_EXT) ||
+		iaru_base_filename == string("default").append(IARU_FILE_EXT) )
 		if (!iaru_cb_save_as()) return;
 
 	update_header(FROM);
@@ -427,7 +429,7 @@ void iaru_cb_load_template()
 	string iaru_def_filename = iaru_def_template_name;
 	const char *p = FSEL::select(
 			"Open template file",
-			"Template file\t*"IARU_TEMP_EXT,
+			string("Template file\t*").append(IARU_TEMP_EXT).c_str(),
 			iaru_def_filename.c_str());
 	if (p) {
 		iaru_clear_form();
@@ -447,7 +449,7 @@ void iaru_cb_save_template()
 	string iaru_def_filename = iaru_def_template_name;
 	const char *p = FSEL::saveas(
 			"Save template file",
-			"Template file\t*"IARU_TEMP_EXT,
+			string("Template file\t*").append(IARU_TEMP_EXT).c_str(),
 			iaru_def_filename.c_str());
 	if (p) {
 		update_header(CHANGED);
@@ -463,7 +465,7 @@ void iaru_cb_save_as_template()
 	string iaru_def_filename = iaru_def_template_name;
 	const char *p = FSEL::saveas(
 			"Save as template file",
-			"Template file\t*"IARU_TEMP_EXT,
+			string("Template file\t*").append(IARU_TEMP_EXT).c_str(),
 			iaru_def_filename.c_str());
 	if (p) {
 		const char *pext = fl_filename_ext(p);
@@ -485,8 +487,10 @@ void iaru_cb_save_as_template()
 
 void iaru_cb_open()
 {
-	const char *p = FSEL::select(_("Open data file"), "iaru\t*"IARU_FILE_EXT,
-					iaru_def_filename.c_str());
+	const char *p = FSEL::select(
+			_("Open data file"),
+			string("iaru\t*").append(IARU_FILE_EXT).c_str(),
+			iaru_def_filename.c_str());
 	if (!p) return;
 	if (strlen(p) == 0) return;
 	iaru_clear_form();
@@ -518,7 +522,7 @@ bool iaru_cb_save_as()
 	} else
 		newfilename = iaru_def_filename;
 
-	p = FSEL::saveas(_("Save data file"), "iaru\t*"IARU_FILE_EXT,
+	p = FSEL::saveas(_("Save data file"), std::string("iaru\t*").append(IARU_FILE_EXT).c_str(),
 						newfilename.c_str());
 
 	if (!p) return false;
@@ -532,15 +536,9 @@ bool iaru_cb_save_as()
 		progStatus.rgnbr = szn;
 		txt_rgnbr->value(szn);
 		txt_rgnbr->redraw();
-	} else if (progStatus.sernbr_fname) {
-		int n = atoi(progStatus.sernbr.c_str());
-		n++;
-		char szn[10];
-		snprintf(szn, sizeof(szn), "%d", n);
-		progStatus.sernbr = szn;
-		txt_sernbr->value(szn);
-		txt_sernbr->redraw();
-	}
+	} else if (progStatus.sernbr_fname)
+		update_sernbr();
+
 	const char *pext = fl_filename_ext(p);
 	iaru_def_filename = p;
 	if (strlen(pext) == 0) iaru_def_filename.append(IARU_FILE_EXT);
@@ -560,8 +558,8 @@ bool iaru_cb_save_as()
 
 void iaru_cb_save()
 {
-	if (iaru_base_filename == "new"IARU_FILE_EXT || 
-		iaru_base_filename == "default"IARU_FILE_EXT ||
+	if (iaru_base_filename == std::string("new").append(IARU_FILE_EXT) || 
+		iaru_base_filename == std::string("default").append(IARU_FILE_EXT) ||
 		iaru_using_template == true) {
 		iaru_cb_save_as();
 		return;
@@ -655,7 +653,7 @@ void iaru_cb_check()
 	char snum[10];
 	snprintf(snum, sizeof(snum), "%s%d", 
 		temp.find("ARL") != string::npos ? "ARL " : "",
-		numwords);
+		(numwords % 1000));
 	iaru_txt_check->value(snum);
 	iaru_update_fields();
 	iaru_btn_check->labelcolor(FL_BLACK);
@@ -666,7 +664,7 @@ void iaru_cb_html()
 {
 	string iaru_name;
 	string html_text;
-	size_t nbr;
+	unsigned int nbr;
 	iaru_name = ICS_dir;
 	iaru_name.append("iaru.html");
 
@@ -676,7 +674,7 @@ void iaru_cb_html()
 
 	for (int i = 0; i < iaru_num_fields; i++) {
 		if (iaru_fields[i].f_type == iaru_prec) {
-			sscanf(iaru_fields[i].f_data.c_str(), "%d", &nbr);
+			sscanf(iaru_fields[i].f_data.c_str(), "%u", &nbr);
 			if (nbr >= 0 && nbr < (sizeof(iaru_s_prec) / sizeof(*iaru_s_prec)))
 				html_text = iaru_s_prec[nbr];
 			else
