@@ -56,6 +56,9 @@ extern int parse_args(int argc, char **argv, int& idx);
 extern void showoptions();
 
 extern Fl_Double_Window *mainwindow;
+extern Fl_Double_Window *expert_dialog;
+extern Fl_Double_Window *tyro_dialog;
+
 extern Fl_Double_Window *optionswindow;
 extern Fl_Double_Window *arlwindow;
 extern Fl_Double_Window *config_files_window;
@@ -67,6 +70,8 @@ extern string flmsgHomeDir;
 extern string IcsHomeDir;
 
 extern bool printme;
+extern bool update_custom;
+//extern bool flmsg_editor;
 
 extern int arl_nbr;
 
@@ -84,8 +89,10 @@ extern string ICS_msg_dir;
 extern string ICS_tmp_dir;
 extern string CSV_dir;
 extern string CUSTOM_dir;
+extern string FLMSG_custom_dir;
 extern string XFR_dir;
 extern string FLMSG_temp_dir;
+extern string FLMSG_log_dir;
 
 extern string title;
 extern string buffer;
@@ -106,6 +113,7 @@ extern void cb_text();
 extern void cb_import();
 extern void cb_export();
 extern void cb_wrap_import();
+extern void wrap_import(const char *fname);
 extern void cb_wrap_export();
 extern void cb_wrap_autosend();
 extern void cb_exit();
@@ -117,6 +125,8 @@ extern void cb_config_date_time();
 extern void cb_config_personal();
 extern void cb_config_radiogram();
 extern void cb_config_socket();
+extern void cb_config_arq();
+extern void cb_config_UI();
 extern void showoptions();
 extern void show_help();
 extern void custom_download();
@@ -159,6 +169,8 @@ extern void drop_box_changed();
 
 extern int eval_transfer_size();
 
+extern void extract_text(string &buffer, const char *fname);
+
 // used by all form management
 
 extern string lineout( string &, string & );
@@ -179,6 +191,8 @@ extern void   replacestr(string &form, string &where, string &what);
 extern void   replacelf(string &form, int n = 0);
 extern void   striplf(string &);
 
+extern void   update_sernbr();
+
 extern void print_and_exit();
 
 // ham_form
@@ -1251,8 +1265,7 @@ extern void cb_transfer_save_template();
 extern void cb_transfer_save_as_template();
 extern void cb_transfer_open();
 extern void write_transfer(string s);
-extern bool cb_transfer_save_as();
-extern void cb_transfer_save();
+extern void cb_transfer_open_as();
 extern void cb_transfer_msg_type();
 extern void cb_transfer_html();
 extern void cb_transfer_textout();
