@@ -37,14 +37,17 @@
 #include <FL/Fl_Box.H>
 #include <FL/Fl_Scroll.H>
 #include <FL/Fl_Browser.H>
+#include <FL/Fl_Hold_Browser.H>
 #include <FL/Fl_Return_Button.H>
 #include <FL/Fl_Input.H>
 #include <FL/Fl_Round_Button.H>
 #include <FL/Fl_Spinner.H>
 #include <FL/Fl_Counter.H>
+#include <FL/Fl_Progress.H>
 
 #include "FTextView.h"
 #include "flinput2.h"
+#include "flslider2.h"
 #include "combo.h"
 #include "calendar.h"
 #include "flmsg.h"
@@ -64,6 +67,8 @@ extern Fl_Double_Window* flmsg_dialog();
 extern Fl_Menu_Item menu_[];
 extern void load_custom_menu();
 
+extern void ARQdropdown(bool on);
+
 extern Fl_Browser	*brwsOptions;
 
 extern Fl_Double_Window* create_config_dialog();
@@ -74,6 +79,32 @@ extern Fl_Group	*tab_config_radiogram;
 extern Fl_Group	*tab_files;
 extern Fl_Group	*tab_headers;
 extern Fl_Group	*tab_socket;
+extern Fl_Group	*tab_arq;
+extern Fl_Group *tab_UI;
+
+//======================================================================
+// events
+extern Fl_Double_Window* create_ARQ_event_dialog();
+extern void add_event(string s);
+extern Fl_Browser *btext;
+//======================================================================
+// rcvd msgs
+extern Fl_Double_Window *rcvd_msgs_dialog;
+extern Fl_Double_Window *create_rcvd_msgs_dialog();
+extern void add_rcvd_msg(string s);
+//======================================================================
+// custom editor
+extern Fl_Double_Window *edit_view_dialog();
+
+//======================================================================
+//----------------------------------------------------------------------
+// arq transfer controls group
+//----------------------------------------------------------------------
+extern Fl_Group		*arq_group;
+extern Fl_Progress	*prgSTATE;
+extern Fl_Input2	*txtSTATE;
+extern Fl_Input2	*txtSENDTO;
+extern Fl_Button	*btnSEND;
 
 extern Fl_Double_Window* optionsdialog();
 extern Fl_Return_Button	*btnCloseOptions;
@@ -96,6 +127,7 @@ extern Fl_Round_Button	*btn_dtformat0;
 extern Fl_Round_Button	*btn_dtformat1;
 extern Fl_Round_Button	*btn_dtformat2;
 extern Fl_Round_Button	*btn_dtformat3;
+extern Fl_Round_Button	*btn_dtformat4;
 extern Fl_Round_Button	*btn_utc_format0;
 extern Fl_Round_Button	*btn_utc_format1;
 extern Fl_Round_Button	*btn_utc_format2;
@@ -129,7 +161,7 @@ extern Fl_Input2	*txt_rgnbr;
 extern Fl_Check_Button	*btn_open_on_export;
 extern Fl_Check_Button	*btn_use_compression;
 extern Fl_Check_Button	*btn_call_fname;
-extern Fl_Check_Button	*btn_dt_fname;
+extern Fl_ListBox		*cbo_dt_fname;
 extern Fl_Check_Button	*btn_sernbr_fname;
 extern Fl_Input2	*txt_sernbr;
 extern Fl_Input2	*txt_mars_roster_file;
