@@ -440,7 +440,7 @@ void cb_rg_new()
 	clear_rg_form();
 	clear_header();
 	def_rg_filename = ICS_msg_dir;
-	def_rg_filename.append("new"RGFILE_EXT);
+	def_rg_filename.append("new").append(RGFILE_EXT);
 	using_rg_template = false;
 	show_filename(def_rg_filename);
 }
@@ -515,7 +515,8 @@ void cb_rg_wrap_export()
 	}
 	update_rgfields();
 
-	if (base_rg_filename == "new"RGFILE_EXT || base_rg_filename == "default"RGFILE_EXT)
+	if (base_rg_filename == string("new").append(RGFILE_EXT) ||
+		base_rg_filename == string("default").append(RGFILE_EXT) )
 		if (!cb_rg_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
@@ -554,7 +555,8 @@ void cb_rg_wrap_autosend()
 	}
 	update_rgfields();
 
-	if (base_rg_filename == "new"RGFILE_EXT || base_rg_filename == "default"RGFILE_EXT)
+	if (base_rg_filename == string("new").append(RGFILE_EXT) ||
+		base_rg_filename == string("default").append(RGFILE_EXT) )
 		if (!cb_rg_save_as()) return;
 
 	update_header(FROM);
@@ -572,7 +574,7 @@ void cb_rg_load_template()
 	string def_rg_filename = def_rg_TemplateName;
 	const char *p = FSEL::select(
 			"Open template file",
-			"Template file\t*"RGTEMP_EXT,
+			string("Template file\t*").append(RGTEMP_EXT).c_str(),
 			def_rg_filename.c_str());
 	if (p) {
 		clear_rg_form();
@@ -592,7 +594,7 @@ void cb_rg_save_template()
 	string def_rg_filename = def_rg_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save template file",
-			"Template file\t*"RGTEMP_EXT,
+			string("Template file\t*").append(RGTEMP_EXT).c_str(),
 			def_rg_filename.c_str());
 	if (p) {
 		update_header(CHANGED);
@@ -608,7 +610,7 @@ void cb_rg_save_as_template()
 	string def_rg_filename = def_rg_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save as template file",
-			"Template file\t*"RGTEMP_EXT,
+			string("Template file\t*").append(RGTEMP_EXT).c_str(),
 			def_rg_filename.c_str());
 	if (p) {
 		const char *pext = fl_filename_ext(p);
@@ -629,8 +631,10 @@ void cb_rg_save_as_template()
 
 void cb_rg_open()
 {
-	const char *p = FSEL::select(_("Open data file"), "radiogram\t*"RGFILE_EXT,
-					def_rg_filename.c_str());
+	const char *p = FSEL::select(
+			_("Open data file"),
+			string("radiogram\t*").append(RGFILE_EXT).c_str(),
+			def_rg_filename.c_str());
 	if (!p) return;
 	if (strlen(p) == 0) return;
 	clear_rg_form();
@@ -661,8 +665,10 @@ bool cb_rg_save_as()
 		newfilename.append(name);
 	} else
 		newfilename = def_rg_filename;
-	p = FSEL::saveas(_("Save data file"), "radiogram\t*"RGFILE_EXT,
-						newfilename.c_str());
+	p = FSEL::saveas(
+			_("Save data file"),
+			string("radiogram\t*").append(RGFILE_EXT).c_str(),
+			newfilename.c_str());
 
 	if (!p) return false;
 	if (strlen(p) == 0) return false;
@@ -675,15 +681,9 @@ bool cb_rg_save_as()
 		progStatus.rgnbr = szn;
 		txt_rgnbr->value(szn);
 		txt_rgnbr->redraw();
-	} else if (progStatus.sernbr_fname) {
-		int n = atoi(progStatus.sernbr.c_str());
-		n++;
-		char szn[10];
-		snprintf(szn, sizeof(szn), "%d", n);
-		progStatus.sernbr = szn;
-		txt_sernbr->value(szn);
-		txt_sernbr->redraw();
-	}
+	} else if (progStatus.sernbr_fname)
+		update_sernbr();
+
 	const char *pext = fl_filename_ext(p);
 	def_rg_filename = p;
 	if (strlen(pext) == 0) def_rg_filename.append(RGFILE_EXT);
@@ -703,8 +703,8 @@ bool cb_rg_save_as()
 
 void cb_rg_save()
 {
-	if (base_rg_filename == "new"RGFILE_EXT || 
-		base_rg_filename == "default"RGFILE_EXT ||
+	if (base_rg_filename == string("new").append(RGFILE_EXT) || 
+		base_rg_filename == string("default").append(RGFILE_EXT) ||
 		using_rg_template == true) {
 		cb_rg_save_as();
 		return;
@@ -796,7 +796,7 @@ void cb_rg_check()
 	txt_rg_msg->clear();
 	txt_rg_msg->addstr(temp.c_str());
 
-	char snum[10];
+	char snum[15];
 	snprintf(snum, sizeof(snum), "%s%d", 
 		temp.find("ARL") != string::npos ? "ARL " : "",
 		numwords);
@@ -810,17 +810,19 @@ void cb_rg_html()
 {
 	string rgname;
 	string html_text;
-	size_t nbr;
+	unsigned int nbr;
 	rgname = ICS_dir;
 	rgname.append("radiogram.html");
 
 	update_rgfields();
 	cb_rg_check();
-	string form = rg_html_template;
+	string form;
+	if (progStatus.rri) form = rri_html_template;
+	else form = rg_html_template;
 
 	for (int i = 0; i < num_rgfields; i++) {
 		if (rgfields[i].f_type == _rg_prec) {
-			sscanf(rgfields[i].f_data.c_str(), "%d", &nbr);
+			sscanf(rgfields[i].f_data.c_str(), "%u", &nbr);
 			if (nbr >= 0 && nbr < (sizeof(s_prec) / sizeof(*s_prec)))
 				html_text = s_prec[nbr];
 			else
@@ -858,17 +860,19 @@ void cb_rg_html_fcopy()
 	string rgname;
 	string MSG = "";
 	string html_text;
-	size_t nbr;
+	unsigned int nbr;
 	rgname = ICS_dir;
 	rgname.append("rg_file_copy.html");
 
 	update_rgfields();
 	cb_rg_check();
-	string form = rg_html_fcopy_template;
+	string form;
+	if (progStatus.rri) form = rri_html_fcopy_template;
+	else form = rg_html_fcopy_template;
 
 	for (int i = 0; i < num_rgfields; i++) {
 		if (rgfields[i].f_type == _rg_prec) {
-			sscanf(rgfields[i].f_data.c_str(), "%d", &nbr);
+			sscanf(rgfields[i].f_data.c_str(), "%u", &nbr);
 			if (nbr >= 0 && nbr < (sizeof(s_prec) / sizeof(*s_prec)))
 				html_text = s_prec[nbr];
 			else
@@ -900,19 +904,21 @@ void cb_rg_textout()
 	string rgname;
 	string lines;
 	string str;
-	size_t nbr = 0;
+	unsigned int nbr = 0;
 	rgname = ICS_dir;
 	rgname.append("radiogram.txt");
 
 	update_rgfields();
 	cb_rg_check();
 
-	string form = rg_txt_template;
+	string form;
+	if (progStatus.rri) form = rri_txt_template;
+	else form = rg_txt_template;
 
 	for (int i = 0; i < num_rgfields; i++) {
 		str.clear();
 		if (rgfields[i].f_type == _rg_prec) {
-			sscanf(rgfields[i].f_data.c_str(), "%d", &nbr);
+			sscanf(rgfields[i].f_data.c_str(), "%u", &nbr);
 			if (nbr < 0) nbr = 0;
 			if (nbr >= sizeof(s_prec)/sizeof(*s_prec)) nbr = 0;
 			str = s_prec[nbr];
