@@ -468,7 +468,7 @@ void cb_redx_5739B_new()
 	clear_redx_5739B_form();
 	clear_header();
 	def_redx_5739B_filename = ICS_msg_dir;
-	def_redx_5739B_filename.append("new"FREDX5739B_EXT);
+	def_redx_5739B_filename.append("new").append(FREDX5739B_EXT);
 	show_filename(def_redx_5739B_filename);
 	using_redx_5739B_template = false;
 }
@@ -519,7 +519,8 @@ void cb_redx_5739B_wrap_export()
 	}
 	update_redx_5739Bfields();
 
-	if (base_redx_5739B_filename == "new"FREDX5739B_EXT || base_redx_5739B_filename == "default"FREDX5739B_EXT)
+	if (base_redx_5739B_filename == string("new").append(FREDX5739B_EXT) ||
+		base_redx_5739B_filename == string("default").append(FREDX5739B_EXT) )
 		if (!cb_redx_5739B_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
@@ -553,7 +554,8 @@ void cb_redx_5739B_wrap_autosend()
 	}
 	update_redx_5739Bfields();
 
-	if (base_redx_5739B_filename == "new"FREDX5739B_EXT || base_redx_5739B_filename == "default"FREDX5739B_EXT)
+	if (base_redx_5739B_filename == string("new").append(FREDX5739B_EXT) ||
+		base_redx_5739B_filename == string("default").append(FREDX5739B_EXT) ) 
 		if (!cb_redx_5739B_save_as()) return;
 
 	update_header(FROM);
@@ -571,7 +573,7 @@ void cb_redx_5739B_load_template()
 	string def_redx_5739B_filename = def_redx_5739B_TemplateName;
 	const char *p = FSEL::select(
 			"Open template file",
-			"Template file\t*"TREDX5739B_EXT,
+			string("Template file\t*").append(TREDX5739B_EXT).c_str(),
 			def_redx_5739B_filename.c_str());
 	if (p) {
 		clear_redx_5739B_form();
@@ -591,7 +593,7 @@ void cb_redx_5739B_save_template()
 	string def_redx_5739B_filename = def_redx_5739B_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save template file",
-			"Template file\t*"TREDX5739B_EXT,
+			string("Template file\t*").append(TREDX5739B_EXT).c_str(),
 			def_redx_5739B_filename.c_str());
 	if (p) {
 		update_header(CHANGED);
@@ -607,7 +609,7 @@ void cb_redx_5739B_save_as_template()
 	string def_redx_5739B_filename = def_redx_5739B_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save as template file",
-			"Template file\t*"TREDX5739B_EXT,
+			string("Template file\t*").append(TREDX5739B_EXT).c_str(),
 			def_redx_5739B_filename.c_str());
 	if (p) {
 		const char *pext = fl_filename_ext(p);
@@ -629,8 +631,10 @@ void cb_redx_5739B_save_as_template()
 
 void cb_redx_5739B_open()
 {
-	const char *p = FSEL::select(_("Open data file"), "ICS-redx_5739B\t*"FREDX5739B_EXT,
-					def_redx_5739B_filename.c_str());
+	const char *p = FSEL::select(
+			_("Open data file"),
+			string("ICS-redx_5739B\t*").append(FREDX5739B_EXT).c_str(),
+			def_redx_5739B_filename.c_str());
 	if (!p) return;
 	if (strlen(p) == 0) return;
 	clear_redx_5739B_form();
@@ -663,24 +667,15 @@ bool cb_redx_5739B_save_as()
 	} else
 		newfilename = def_redx_5739B_filename;
 
-	p = FSEL::saveas(_("Save data file"), "ICS-redx_5739B\t*"FREDX5739B_EXT,
-					newfilename.c_str());
+	p = FSEL::saveas(
+			_("Save data file"),
+			string("ICS-redx_5739B\t*").append(FREDX5739B_EXT).c_str(),
+			newfilename.c_str());
 
 	if (!p) return false;
 	if (strlen(p) == 0) return false;
 
-	if (progStatus.sernbr_fname) {
-		string haystack = p;
-		if (haystack.find(newfilename) != string::npos) {
-			int n = atoi(progStatus.sernbr.c_str());
-			n++;
-			char szn[10];
-			snprintf(szn, sizeof(szn), "%d", n);
-			progStatus.sernbr = szn;
-			txt_sernbr->value(szn);
-			txt_sernbr->redraw();
-		}
-	}
+	if (progStatus.sernbr_fname) update_sernbr();
 
 	const char *pext = fl_filename_ext(p);
 	def_redx_5739B_filename = p;
@@ -701,8 +696,8 @@ bool cb_redx_5739B_save_as()
 
 void cb_redx_5739B_save()
 {
-	if (base_redx_5739B_filename == "new"FREDX5739B_EXT || 
-		base_redx_5739B_filename == "default"FREDX5739B_EXT ||
+	if (base_redx_5739B_filename == string("new").append(FREDX5739B_EXT) || 
+		base_redx_5739B_filename == string("default").append(FREDX5739B_EXT) ||
 		using_redx_5739B_template == true) {
 		cb_redx_5739B_save_as();
 		return;
