@@ -3,24 +3,25 @@
 //
 // Copyright (C) 2007-2009
 //              Stelios Bounanos, M0GLD
-// ----------------------------------------------------------------------------
-// Copyright (C) 2014
-//              David Freese, W1HKJ
 //
-// This file is part of flmsg
+// Copyright (C) 2008-2009
+//              Dave Freese, W1HKJ
 //
-// flrig is free software; you can redistribute it and/or modify
+// This file is part of flmsg.
+//
+// This is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
-// flrig is distributed in the hope that it will be useful,
+// This software is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
+//
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -56,20 +57,20 @@ using namespace std;
 
 /// FTextBase constructor.
 /// Word wrapping is enabled by default at column 80, but see \c reset_wrap_col.
-/// @param x 
-/// @param y 
-/// @param w 
-/// @param h 
-/// @param l 
+/// @param x
+/// @param y
+/// @param w
+/// @param h
+/// @param l
 
-#if FLMSG_FLTK_API_MAJOR == 1 && FLMSG_FLTK_API_MINOR < 3
+#if flmsg_FLTK_API_MAJOR == 1 && flmsg_FLTK_API_MINOR < 3
 FTextBase::FTextBase(int x, int y, int w, int h, const char *l)
-	: Fl_Text_Editor_mod(x, y, w, h, l),
-          wrap(true), wrap_col(80), max_lines(0), scroll_hint(false)
+: Fl_Text_Editor_mod(x, y, w, h, l),
+wrap(true), wrap_col(80), max_lines(0), scroll_hint(false)
 #else
 FTextBase::FTextBase(int x, int y, int w, int h, const char *l)
-	: Fl_Text_Editor_mod(x, y, w, h, l),
-          wrap(WRAP_AT_BOUNDS), wrap_col(80), max_lines(0), scroll_hint(false)
+: Fl_Text_Editor_mod(x, y, w, h, l),
+wrap(WRAP_AT_BOUNDS), wrap_col(80), max_lines(0), scroll_hint(false)
 #endif
 {
 	oldw = oldh = olds = -1;
@@ -88,7 +89,7 @@ FTextBase::FTextBase(int x, int y, int w, int h, const char *l)
 	restore_wrap = wrap;
 
 	// Do we want narrower scrollbars? The default width is 16.
-	 scrollbar_width((int)floor(scrollbar_width() * 7.0/8.0));
+	scrollbar_width((int)floor(scrollbar_width() * 7.0/8.0));
 
 	reset_styles(SET_FONT | SET_SIZE | SET_COLOR);
 	read_cb = NULL;
@@ -118,8 +119,8 @@ int FTextBase::handle(int event)
 
 /// @see FTextRX::add
 ///
-/// @param s 
-/// @param attr 
+/// @param s
+/// @param attr
 ///
 void FTextBase::add(const char *s, int attr)
 {
@@ -135,12 +136,12 @@ void FTextBase::add(const char *s, int attr)
 
 /// @see FTextBase::add
 ///
-/// @param s 
-/// @param attr 
+/// @param s
+/// @param attr
 ///
 void FTextBase::add(unsigned char c, int attr)
 {
-	char s[] = { FTEXT_DEF + attr, '\0' };
+	char s[] = { static_cast<char>(FTEXT_DEF + attr), '\0' };
 	sbuf->replace(insert_position(), insert_position() + 1, s);
 
 	s[0] = c;
@@ -149,7 +150,7 @@ void FTextBase::add(unsigned char c, int attr)
 
 void FTextBase::set_word_wrap(bool b)
 {
-#if FLMSG_FLTK_API_MAJOR == 1 && FLMSG_FLTK_API_MINOR < 3
+#if flmsg_FLTK_API_MAJOR == 1 && flmsg_FLTK_API_MINOR < 3
 	if ((wrap = b)) wrap_mode(true, 0);
 	else wrap_mode(false, 0);
 	show_insert_position();
@@ -180,10 +181,10 @@ void FTextBase::setFontColor(Fl_Color c, int attr)
 /// is defined, a version of that code modified so that no horizontal
 /// scrollbars are displayed when word wrapping.
 ///
-/// @param X 
-/// @param Y 
-/// @param W 
-/// @param H 
+/// @param X
+/// @param Y
+/// @param W
+/// @param H
 ///
 void FTextBase::resize(int X, int Y, int W, int H)
 {
@@ -207,14 +208,14 @@ void FTextBase::resize(int X, int Y, int W, int H)
 	if (need_wrap_reset)
 		reset_wrap_col();
 
-#if FLMSG_FLTK_API_MAJOR == 1 && FLMSG_FLTK_API_MINOR == 3
+#if flmsg_FLTK_API_MAJOR == 1 && flmsg_FLTK_API_MINOR == 3
 	TOP_MARGIN = DEFAULT_TOP_MARGIN;
 	int r = H - Fl::box_dh(box()) - TOP_MARGIN - BOTTOM_MARGIN;
 	if (mHScrollBar->visible())
 		r -= scrollbar_width();
 	int msize = mMaxsize ? mMaxsize : textsize();
 	if (!msize) msize = 1;
-//printf("H %d, textsize %d, lines %d, extra %d\n", r, msize, r / msize, r % msize);
+	//printf("H %d, textsize %d, lines %d, extra %d\n", r, msize, r / msize, r % msize);
 	if (r %= msize)
 		TOP_MARGIN += r;
 #else
@@ -230,7 +231,7 @@ void FTextBase::resize(int X, int Y, int W, int H)
 	if (scroll_hint) {
 		mTopLineNumHint = mNBufferLines;
 		mHorizOffsetHint = 0;
-//		display_insert_position_hint = 1;
+		//		display_insert_position_hint = 1;
 		scroll_hint = false;
 	}
 
@@ -365,7 +366,7 @@ int FTextBase::readFile(const char* fn)
 ///
 void FTextBase::saveFile(void)
 {
- 	const char *fn = FSEL::saveas(_("Save text as"), "Text\t*.txt");
+	const char *fn = FSEL::saveas(_("Save text as"), "Text\t*.txt");
 	if (fn) {
 #ifdef __WOE32__
 		ofstream tfile(fn);
@@ -397,8 +398,8 @@ void FTextBase::saveFile(void)
 /// If \a ontext is true, this function will return text only if the
 /// mouse cursor position is inside the text range.
 ///
-/// @param x 
-/// @param y 
+/// @param x
+/// @param y
 ///
 /// @return The selection, or the word text at (x,y). <b>Must be freed by the caller</b>.
 ///
@@ -414,10 +415,6 @@ char* FTextBase::get_word(int x, int y, const char* nwchars, bool ontext)
 			return tbuf->selection_text();
 	}
 
-//#if FLMSG_FLTK_API_MAJOR == 1 && FLMSG_FLTK_API_MINOR == 3
-//	start = tbuf->word_start(p);
-//	end = tbuf->word_end(p);
-//#else
 	string nonword = nwchars;
 	nonword.append(" \t\n");
 	if (!tbuf->findchars_backward(p, nonword.c_str(), &start))
@@ -426,7 +423,7 @@ char* FTextBase::get_word(int x, int y, const char* nwchars, bool ontext)
 		start++;
 	if (!tbuf->findchars_forward(p, nonword.c_str(), &end))
 		end = tbuf->length();
-//#endif
+	//#endif
 
 	if (ontext && (p < start || p >= end))
 		return 0;
@@ -440,8 +437,8 @@ void FTextBase::init_context_menu(void)
 {
 	for (int i = 0; i < context_menu->size() - 1; i++) {
 		if (context_menu[i].user_data() == 0 &&
-		    context_menu[i].labeltype() == _FL_MULTI_LABEL) {
-			set_icon_label(&context_menu[i]);
+			context_menu[i].labeltype() == _FL_MULTI_LABEL) {
+			icons::set_icon_label(&context_menu[i]);
 			context_menu[i].user_data(this);
 		}
 	}
@@ -498,10 +495,10 @@ void FTextBase::reset_styles(int set)
 // ----------------------------------------------------------------------------
 
 Fl_Menu_Item FTextView::menu[] = {
-	{ make_icon_label(_("Copy"), edit_copy_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Clear"), edit_clear_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Select All"), edit_select_all_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Save as..."), save_as_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Copy"), edit_copy_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Clear"), edit_clear_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Select All"), edit_select_all_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Save as..."), save_as_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
 	{ _("Word wrap"),       0, 0, 0, FL_MENU_TOGGLE, FL_NORMAL_LABEL },
 	{ 0 }
 };
@@ -510,13 +507,13 @@ Fl_Menu_Item FTextView::menu[] = {
 /// We remove \c Fl_Text_Display_mod::buffer_modified_cb from the list of callbacks
 /// because we want to scroll depending on the visibility of the last line; @see
 /// changed_cb.
-/// @param x 
-/// @param y 
-/// @param w 
-/// @param h 
-/// @param l 
+/// @param x
+/// @param y
+/// @param w
+/// @param h
+/// @param l
 FTextView::FTextView(int x, int y, int w, int h, const char *l)
-        : FTextBase(x, y, w, h, l), quick_entry(false)
+: FTextBase(x, y, w, h, l), quick_entry(false)
 {
 	tbuf->remove_modify_callback(buffer_modified_cb, this);
 	tbuf->add_modify_callback(changed_cb, this);
@@ -535,35 +532,35 @@ FTextView::FTextView(int x, int y, int w, int h, const char *l)
 /// pasting) and keyboard events (to make sure no text can be inserted).
 /// Everything else is passed to the base class handle().
 ///
-/// @param event 
+/// @param event
 ///
-/// @return 
+/// @return
 ///
 int FTextView::handle(int event)
 {
 	switch (event) {
-	case FL_PUSH:
-		if (!Fl::event_inside(this))
+		case FL_PUSH:
+			if (!Fl::event_inside(this))
+				break;
+			if (Fl::event_button() == FL_RIGHT_MOUSE) {
+				handle_context_menu();
+				return 1;
+			}
 			break;
- 		if (Fl::event_button() == FL_RIGHT_MOUSE) {
-			handle_context_menu();
-			return 1;
- 		}
-		break;
-	case FL_DRAG:
-		if (Fl::event_button() != FL_LEFT_MOUSE)
-			return 1;
-		break;
-	// catch some text-modifying events that are not handled by kf_* functions
-	case FL_KEYBOARD:
-		int k;
-		if (Fl::compose(k))
-			return 1;
-		k = Fl::event_key();
-		if (k == FL_BackSpace)
-			return 1;
-		else if (k == FL_Tab)
-			return Fl_Widget::handle(event);
+		case FL_DRAG:
+			if (Fl::event_button() != FL_LEFT_MOUSE)
+				return 1;
+			break;
+			// catch some text-modifying events that are not handled by kf_* functions
+		case FL_KEYBOARD:
+			int k;
+			if (Fl::compose(k))
+				return 1;
+			k = Fl::event_key();
+			if (k == FL_BackSpace)
+				return 1;
+			else if (k == FL_Tab)
+				return Fl_Widget::handle(event);
 	}
 
 	return FTextBase::handle(event);
@@ -571,10 +568,10 @@ int FTextView::handle(int event)
 
 void FTextView::handle_context_menu(void)
 {
-	set_active(&menu[VIEW_MENU_COPY], tbuf->selected());
-	set_active(&menu[VIEW_MENU_CLEAR], tbuf->length());
-	set_active(&menu[VIEW_MENU_SELECT_ALL], tbuf->length());
-	set_active(&menu[VIEW_MENU_SAVE], tbuf->length());
+	icons::set_active(&menu[VIEW_MENU_COPY], tbuf->selected());
+	icons::set_active(&menu[VIEW_MENU_CLEAR], tbuf->length());
+	icons::set_active(&menu[VIEW_MENU_SELECT_ALL], tbuf->length());
+	icons::set_active(&menu[VIEW_MENU_SAVE], tbuf->length());
 	if (wrap)
 		menu[VIEW_MENU_WRAP].set();
 	else
@@ -585,39 +582,39 @@ void FTextView::handle_context_menu(void)
 
 /// The context menu handler
 ///
-/// @param val 
+/// @param val
 ///
 void FTextView::menu_cb(size_t item)
 {
 	switch (item) {
-	case VIEW_MENU_COPY:
-		kf_copy(Fl::event_key(), this);
-		break;
-	case VIEW_MENU_CLEAR:
-		clear();
-		break;
-	case VIEW_MENU_SELECT_ALL:
-		tbuf->select(0, tbuf->length());
-		break;
-	case VIEW_MENU_SAVE:
-		saveFile();
-		break;
-	case VIEW_MENU_WRAP:
-		set_word_wrap(!wrap);
-		restore_wrap = wrap;
-		break;
+		case VIEW_MENU_COPY:
+			kf_copy(Fl::event_key(), this);
+			break;
+		case VIEW_MENU_CLEAR:
+			clear();
+			break;
+		case VIEW_MENU_SELECT_ALL:
+			tbuf->select(0, tbuf->length());
+			break;
+		case VIEW_MENU_SAVE:
+			saveFile();
+			break;
+		case VIEW_MENU_WRAP:
+			set_word_wrap(!wrap);
+			restore_wrap = wrap;
+			break;
 	}
 }
 
 /// Scrolls down if the buffer has been modified and the last line is
 /// visible. See Fl_Text_Buffer::add_modify_callback() for parameter details.
 ///
-/// @param pos 
-/// @param nins 
-/// @param ndel 
-/// @param nsty 
-/// @param dtext 
-/// @param arg 
+/// @param pos
+/// @param nins
+/// @param ndel
+/// @param nsty
+/// @param dtext
+/// @param arg
 ///
 inline
 void FTextView::changed_cb(int pos, int nins, int ndel, int nsty, const char *dtext, void *arg)
@@ -639,10 +636,10 @@ void FTextView::changed_cb(int pos, int nins, int ndel, int nsty, const char *dt
 void FTextView::change_keybindings(void)
 {
 	Fl_Text_Editor_mod::Key_Func fdelete[] = { Fl_Text_Editor_mod::kf_default,
-					       Fl_Text_Editor_mod::kf_enter,
-					       Fl_Text_Editor_mod::kf_delete,
-					       Fl_Text_Editor_mod::kf_cut,
-					       Fl_Text_Editor_mod::kf_paste };
+		Fl_Text_Editor_mod::kf_enter,
+		Fl_Text_Editor_mod::kf_delete,
+		Fl_Text_Editor_mod::kf_cut,
+		Fl_Text_Editor_mod::kf_paste };
 	int n = sizeof(fdelete) / sizeof(fdelete[0]);
 
 	// walk the keybindings linked list and delete items containing elements
@@ -662,17 +659,17 @@ loop:
 
 
 Fl_Menu_Item FTextEdit::menu[] = {
-	{ make_icon_label(_("Cut"), edit_cut_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Copy"), edit_copy_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Paste"), edit_paste_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Clear"), edit_clear_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Insert file..."), file_open_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Cut"), edit_cut_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Copy"), edit_copy_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Paste"), edit_paste_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Clear"), edit_clear_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Insert file..."), file_open_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
 	{ _("Word wrap"), 0, 0, 0, FL_MENU_TOGGLE, FL_NORMAL_LABEL } ,
 	{ 0 }
 };
 
 FTextEdit::FTextEdit(int x, int y, int w, int h, const char *l)
-	: FTextBase(x, y, w, h, l)
+: FTextBase(x, y, w, h, l)
 {
 	tbuf->remove_modify_callback(buffer_modified_cb, this);
 	tbuf->add_modify_callback(changed_cb, this);
@@ -691,9 +688,9 @@ FTextEdit::FTextEdit(int x, int y, int w, int h, const char *l)
 /// the popup menu. We also disallow mouse2 events in the transmitted text area.
 /// Everything else is passed to the base class handle().
 ///
-/// @param event 
+/// @param event
 ///
-/// @return 
+/// @return
 ///
 int FTextEdit::handle(int event)
 {
@@ -701,31 +698,31 @@ int FTextEdit::handle(int event)
 		return FTextBase::handle(event);
 
 	switch (event) {
-	case FL_KEYBOARD:
-		return handle_key(Fl::event_key()) ? 1 : FTextBase::handle(event);
-	case FL_DND_RELEASE:
-		dnd_paste = true;
-		// fall through
-	case FL_DND_ENTER: case FL_DND_LEAVE:
-		return 1;
-	case FL_DND_DRAG:
-		return handle_dnd_drag(xy_to_position(Fl::event_x(), Fl::event_y(), CHARACTER_POS));
-	case FL_PASTE:
-	{
-		int r = dnd_paste ? handle_dnd_drop() : FTextBase::handle(event);
-		dnd_paste = false;
-		return r;
-	}
-	case FL_PUSH:
-	{
-		int eb = Fl::event_button();
-		if (eb == FL_RIGHT_MOUSE) {
-			handle_context_menu();
+		case FL_KEYBOARD:
+			return handle_key(Fl::event_key()) ? 1 : FTextBase::handle(event);
+		case FL_DND_RELEASE:
+			dnd_paste = true;
+			// fall through
+		case FL_DND_ENTER: case FL_DND_LEAVE:
 			return 1;
+		case FL_DND_DRAG:
+			return handle_dnd_drag(xy_to_position(Fl::event_x(), Fl::event_y(), CHARACTER_POS));
+		case FL_PASTE:
+		{
+			int r = dnd_paste ? handle_dnd_drop() : FTextBase::handle(event);
+			dnd_paste = false;
+			return r;
 		}
-	}
-	default:
-		break;
+		case FL_PUSH:
+		{
+			int eb = Fl::event_button();
+			if (eb == FL_RIGHT_MOUSE) {
+				handle_context_menu();
+				return 1;
+			}
+		}
+		default:
+			break;
 	}
 
 	return FTextBase::handle(event);
@@ -734,14 +731,14 @@ int FTextEdit::handle(int event)
 /// Handles keyboard events to override Fl_Text_Editor_mod's handling of some
 /// keystrokes.
 ///
-/// @param key 
+/// @param key
 ///
-/// @return 
+/// @return
 ///
 int FTextEdit::handle_key(int key)
 {
-// read ctl-ddd, where d is a digit, as ascii characters (in base 10)
-// and insert verbatim; e.g. ctl-001 inserts a <soh>
+	// read ctl-ddd, where d is a digit, as ascii characters (in base 10)
+	// and insert verbatim; e.g. ctl-001 inserts a <soh>
 	if (key == FL_Control_L || key == FL_Control_R) return 0;
 	bool t1 = isdigit(key);
 	bool t2 = false;
@@ -752,13 +749,13 @@ int FTextEdit::handle_key(int key)
 	ascii_cnt = 0; // restart the numeric keypad entries.
 	ascii_chr = 0;
 	return Fl_Text_Editor_mod::handle(FL_KEYBOARD);
-//	return 0;
+	//	return 0;
 }
 
 /// Composes ascii characters and adds them to the FTextEdit buffer.
 /// Control characters are inserted with the CTRL style. Values larger than 127
 /// (0x7f) are ignored. We cannot really add NULs for the time being.
-/// 
+///
 /// @param key A digit character
 ///
 /// @return 1
@@ -806,7 +803,7 @@ int FTextEdit::handle_dnd_drag(int pos)
 /// @return 1 or FTextBase::handle(FL_PASTE)
 int FTextEdit::handle_dnd_drop(void)
 {
-// paste verbatim if the shift key was held down during dnd
+	// paste verbatim if the shift key was held down during dnd
 	if (Fl::event_shift())
 		return FTextBase::handle(FL_PASTE);
 
@@ -830,7 +827,7 @@ int FTextEdit::handle_dnd_drop(void)
 			len -= 7;
 		}
 #endif
-// paste everything verbatim if we cannot read the first file
+		// paste everything verbatim if we cannot read the first file
 		if (readFile(text.c_str()) == -1 && len == text.length())
 			return FTextBase::handle(FL_PASTE);
 		text.erase(0, p + sizeof(sep) - 1);
@@ -841,14 +838,14 @@ int FTextEdit::handle_dnd_drop(void)
 
 /// Handles mouse-3 clicks by displaying the context menu
 ///
-/// @param val 
+/// @param val
 ///
 void FTextEdit::handle_context_menu(void)
 {
 	bool selected = tbuf->selected();
-	set_active(&menu[EDIT_MENU_CUT], selected);
-	set_active(&menu[EDIT_MENU_COPY], selected);
-	set_active(&menu[EDIT_MENU_CLEAR], tbuf->length());
+	icons::set_active(&menu[EDIT_MENU_CUT], selected);
+	icons::set_active(&menu[EDIT_MENU_COPY], selected);
+	icons::set_active(&menu[EDIT_MENU_CLEAR], tbuf->length());
 
 	if (wrap)
 		menu[EDIT_MENU_WRAP].set();
@@ -860,30 +857,30 @@ void FTextEdit::handle_context_menu(void)
 
 /// The context menu handler
 ///
-/// @param val 
+/// @param val
 ///
 void FTextEdit::menu_cb(size_t item)
 {
-  	switch (item) {
-	case EDIT_MENU_CLEAR:
-		clear();
-		break;
-	case EDIT_MENU_CUT:
-		kf_cut(0, this);
-		break;
-	case EDIT_MENU_COPY:
-		kf_copy(0, this);
-		break;
-	case EDIT_MENU_PASTE:
-		kf_paste(0, this);
-		break;
-	case EDIT_MENU_READ:
-		readFile();
-		break;
-	case EDIT_MENU_WRAP:
-		set_word_wrap(!wrap);
-		restore_wrap = wrap;
-		break;
+	switch (item) {
+		case EDIT_MENU_CLEAR:
+			clear();
+			break;
+		case EDIT_MENU_CUT:
+			kf_cut(0, this);
+			break;
+		case EDIT_MENU_COPY:
+			kf_copy(0, this);
+			break;
+		case EDIT_MENU_PASTE:
+			kf_paste(0, this);
+			break;
+		case EDIT_MENU_READ:
+			readFile();
+			break;
+		case EDIT_MENU_WRAP:
+			set_word_wrap(!wrap);
+			restore_wrap = wrap;
+			break;
 	}
 }
 
@@ -896,12 +893,12 @@ void FTextEdit::menu_cb(size_t item)
 /// style buffer to mark the last character in the buffer with the XMIT
 /// attribute.
 ///
-/// @param pos 
-/// @param nins 
-/// @param ndel 
-/// @param nsty 
-/// @param dtext 
-/// @param arg 
+/// @param pos
+/// @param nins
+/// @param ndel
+/// @param nsty
+/// @param dtext
+/// @param arg
 ///
 void FTextEdit::changed_cb(int pos, int nins, int ndel, int nsty, const char *dtext, void *arg)
 {
@@ -915,8 +912,8 @@ void FTextEdit::changed_cb(int pos, int nins, int ndel, int nsty, const char *dt
 		}
 		else if (nsty > 0) // restyled, e.g. selected, text
 			return e->buffer_modified_cb(pos, nins, ndel, nsty, dtext, e);
-
-                // No changes, e.g., a paste with an empty clipboard.
+		
+		// No changes, e.g., a paste with an empty clipboard.
 		return;
 	}
 	else if (nins > 0 && e->sbuf->length() < e->tbuf->length()) {
@@ -937,9 +934,9 @@ void FTextEdit::changed_cb(int pos, int nins, int ndel, int nsty, const char *dt
 	}
 	else if (ndel > 0)
 		e->sbuf->remove(pos, pos + ndel);
-
+	
 	e->sbuf->select(pos, pos + nins - ndel);
-
+	
 	e->buffer_modified_cb(pos, nins, ndel, nsty, dtext, e);
 	// We may need to scroll if the text was inserted by the
 	// add() methods, e.g. by a macro
